clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Independentism pre-post
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

reg indep $controls i.COMARCA [pw= POND_GEO ] if HOR_INI<19 & time<7, cluster(PROVItime)
predict indep_pred, xb

reg indep_pred estatut, cluster(PROVItime)

collapse (mean) meanindep= indep_pred (sd) sdindep=indep_pred (count) N=indep_pred , by(estatut)

generate hiindep = meanindep + invttail(N-1,0.025)*(sdindep / sqrt(N))
generate loindep = meanindep - invttail(N-1,0.025)*(sdindep / sqrt(N))

label define estatutl 0 "Pre-Ruling" 1 "Post-Ruling" 
label values estatut estatutl  

gen aa=1

graph twoway (bar meanindep aa) (rcap hiindep loindep aa), by(estatut, note("") legend(position(6)))  ylabel(0.22(0.01)0.32) xlabel(none) xtitle(" ", margin(small)) legend(label(1 "Mean predicted support for independence") label(2 "Lower-Upper 95% CI") rows(1))
graph export output/fig_rep/figure_predindep.png, as(png) replace

*******************************************************************************
***Catalan identity pre-post
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

reg cat_feeling $controls i.COMARCA [pw= POND_GEO ] if HOR_INI<19 & time<7, cluster(PROVItime)
predict feel_pred, xb

reg feel_pred estatut, cluster(PROVItime)

collapse (mean) meanfeel= feel_pred (sd) sdfeel=feel_pred (count) N=feel_pred , by(estatut)

generate hifeel = meanfeel + invttail(N-1,0.025)*(sdfeel / sqrt(N))
generate lofeel = meanfeel - invttail(N-1,0.025)*(sdfeel / sqrt(N))

label define estatutl 0 "Pre-Ruling" 1 "Post-Ruling" 
label values estatut estatutl  

gen aa=1

graph twoway (bar meanfeel aa) (rcap hifeel lofeel aa), by(estatut, note("") legend(position(6)))  ylabel(3.2(0.1)3.8) xlabel(none) xtitle(" ", margin(small)) legend(label(1 "Mean predicted Catalan self-identification") label(2 "Lower-Upper 95% CI") rows(1))
graph export output/fig_rep/figure_predfeel.png, as(png) replace
