clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Municipality characteristics: database
*******************************************************************************
***Guell, Rodriguez-Mora, and Telmer (2015)'s data
clear all
use data/final/dataGRMT.dta

gen cat_degree_1=Nape1p2catAPE1/Nape1p2spAPE1
gen cat_degree_2=Nape1p2catAPE2/Nape1p2spAPE2
egen cat_degree_1_2=rowmean(cat_degree_1 cat_degree_2)
keep if regionborn<43
collapse (mean) cat_degree_*, by(regionborn)

rename regionborn COMARCA

tempfile t1
save `t1'

***CEO
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

rename CODMUN CODIINE

***Merge with data from Censo 2011 and Padron 2010
merge m:1 CODIINE using data/final/data_padroncenso.dta
drop if _merge==2
drop _merge

***Merge with Guell, Rodriguez-Mora, and Telmer (2015)
merge m:1 COMARCA using `t1'
drop if _merge==2
drop _merge

*******************************************************************************
***Municipality characteristics: regressions
*******************************************************************************
***Local catalanism
matrix coeff = J(1,10,.)
matrix colnames coeff = "Share born in Catalonia" "Share born in rest of Spain" "Share foreign born" "Share understand Catalan" "Share able speak Catalan" "Share able to read Catalan" "Share able to write Catalan" "Mean Catalan degree 1st surname" "Mean Catalan degree 2nd surname" "Mean Catalan degree surnames" 
matrix CI = J(2,10,.)
local i = 0

foreach y in "kat" "esp" "for"{
	gen sh_nac_`y'_10= pob_nac_`y'_10/pob_tot_10
    reg sh_nac_`y'_10 estatut  [pw= POND_GEO ] if HOR_INI<19 & time<7,  rob
	
	local i=`i'+1
	mat coeff[1,`i'] = _b[estatut]
	mat CI[1,`i'] = _b[estatut] + invttail(e(df_r),0.025)*_se[estatut]
	mat CI[2,`i'] = _b[estatut] - invttail(e(df_r),0.025)*_se[estatut]
	}


foreach y in "und" "speak" "read" "write"{
    gen sh_0002_`y'kat_11=pob_0002_`y'kat_11/pob_0002_11
	reg sh_0002_`y'kat_11 estatut  [pw= POND_GEO ] if HOR_INI<19 & time<7,  rob
	
	local i=`i'+1
	mat coeff[1,`i'] = _b[estatut]
	mat CI[1,`i'] = _b[estatut] + invttail(e(df_r),0.025)*_se[estatut]
	mat CI[2,`i'] = _b[estatut] - invttail(e(df_r),0.025)*_se[estatut]

}

foreach y in "cat_degree_1" "cat_degree_2" "cat_degree_1_2"{
	reg `y' estatut  [pw= POND_GEO ] if HOR_INI<19 & time<7,  rob

	local i=`i'+1
	mat coeff[1,`i'] = _b[estatut]
	mat CI[1,`i'] = _b[estatut] + invttail(e(df_r),0.025)*_se[estatut]
	mat CI[2,`i'] = _b[estatut] - invttail(e(df_r),0.025)*_se[estatut]
	}

coefplot matrix(coeff), ci(CI) xline(0) title(Difference post - pre Ruling) levels(95)
graph export output/fig_rep/figure_cplot_balancing_catalanism_noage.png, as(png) replace

***Local catalanism by age
matrix coeff = J(1,14,.)
matrix colnames coeff = "20-24" "25-29" "30-34" "35-39"  "40-44" "45-49" "50-54" "55-59" "60-64" "65-69" "70-74" "75-79" "80-84" "85 or more"   
matrix CI = J(2,14,.)
local l=0

forvalues i=20(5)75{
    local j=`i'+4
	gen sh_nac_kat_`i'`j'_10=pob_nac_kat_`i'`j'/pob_tot_10
	reg sh_nac_kat_`i'`j'_10 estatut  [pw= POND_GEO ] if HOR_INI<19 & time<7,  rob
	
	local l=`l'+1
	mat coeff[1,`l'] = _b[estatut]
	mat CI[1,`l'] = _b[estatut] + invttail(e(df_r),0.025)*_se[estatut]
	mat CI[2,`l'] = _b[estatut] - invttail(e(df_r),0.025)*_se[estatut]
}


gen sh_nac_kat_85_10=pob_nac_kat_85/pob_tot_10
reg sh_nac_kat_85_10 estatut  [pw= POND_GEO ] if HOR_INI<19 & time<7,  rob

local l=`l'+1
mat coeff[1,`l'] = _b[estatut]
mat CI[1,`l'] = _b[estatut] + invttail(e(df_r),0.025)*_se[estatut]
mat CI[2,`l'] = _b[estatut] - invttail(e(df_r),0.025)*_se[estatut]

coefplot matrix(coeff), ci(CI) xline(0) title(Difference post - pre Ruling) levels(95)
graph export output/fig_rep/figure_cplot_balancing_catalanism_age.png, as(png) replace