clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Leaves comarcas out
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Leave one comarca out

*Create one file with the list of comarcas for each placebo

preserve
keep COMARCA
duplicates drop
tempfile comarcas
save `comarcas'

mat def placebos = J(1000,1,.)
forval k = 1(1)1000{
	use `comarcas', clear
	set seed `k'
	gen runif = runiform()
	sort runif
	mat placebos[`k', 1] = COMARCA[1]
}
restore

*Run regression

mat def betas_p = J(1000,1,.)
forval k=1(1)1000{
	local pl = placebos[`k', 1]
	qui areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & COMARCA != `pl', absorb(COMARCA) cluster(PROVItime)
	mat betas_p[`k', 1] = e(b)[1,1]
}

preserve
clear
svmat betas_p 
hist betas_p1, xline(0.13339791) percent 

restore


***Leave two comarcas out

*Create one file with the list of comarcas for each placebo

preserve

mat def placebos = J(1000,2,.)
forval k = 1(1)1000{
	use `comarcas', clear
	set seed `k'
	gen runif = runiform()
	sort runif
	mat placebos[`k', 1] = COMARCA[1]
	mat placebos[`k', 2] = COMARCA[2]
}
restore

*Run regression

mat def betas_p2 = J(1000,1,.)
forval k=1(1)1000{
	local pl = placebos[`k', 1]
	local pl_2 = placebos[`k', 2]
	qui areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & COMARCA != `pl' & COMARCA != `pl_2', absorb(COMARCA) cluster(PROVItime)
	mat betas_p2[`k', 1] = e(b)[1,1]
}

preserve
clear
svmat betas_p2 
hist betas_p21, xline(0.13339791) percent 

restore


***Leave three comarcas out

*Create one file with the list of comarcas for each placebo

preserve

mat def placebos = J(1000,3,.)
forval k = 1(1)1000{
	use `comarcas', clear
	set seed `k'
	gen runif = runiform()
	sort runif
	mat placebos[`k', 1] = COMARCA[1]
	mat placebos[`k', 2] = COMARCA[2]
	mat placebos[`k', 3] = COMARCA[3]
}
restore

*Run regression

mat def betas_p3 = J(1000,1,.)
forval k=1(1)1000{
	local pl = placebos[`k', 1]
	local pl_2 = placebos[`k', 2]
	local pl_3 = placebos[`k', 3]
	qui areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & COMARCA != `pl' & COMARCA != `pl_2' & COMARCA != `pl_3', absorb(COMARCA) cluster(PROVItime)
	mat betas_p3[`k', 1] = e(b)[1,1]
}

***Leave four comarcas out

*Create one file with the list of comarcas for each placebo

preserve

mat def placebos = J(1000,4,.)
forval k = 1(1)1000{
	use `comarcas', clear
	set seed `k'
	gen runif = runiform()
	sort runif
	mat placebos[`k', 1] = COMARCA[1]
	mat placebos[`k', 2] = COMARCA[2]
	mat placebos[`k', 3] = COMARCA[3]
	mat placebos[`k', 4] = COMARCA[4]
}
restore

*Run regression

mat def betas_p4 = J(1000,1,.)
forval k=1(1)1000{
	local pl = placebos[`k', 1]
	local pl_2 = placebos[`k', 2]
	local pl_3 = placebos[`k', 3]
	local pl_4 = placebos[`k', 4]
	qui areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & COMARCA != `pl' & COMARCA != `pl_2' & COMARCA != `pl_3' & COMARCA != `pl_4', absorb(COMARCA) cluster(PROVItime)
	mat betas_p4[`k', 1] = e(b)[1,1]
}


***Combine all the results

svmat betas_p4
svmat betas_p3 
svmat betas_p2
svmat betas_p 

*Regression with all the comarcas

areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

di e(b)[1,1]
local efff=_b[estatut]

local efff_ub = r(table)[6,1]
local efff_lb = r(table)[5,1]


twoway (histogram betas_p41, color(navy) fraction ) (histogram betas_p31, color(ltblue) fraction ) ///
(histogram betas_p21, color(green) fraction)  /// 
       (histogram betas_p1, color(sand) fraction) (scatteri 0 `efff'  0.4 `efff', recast(line) color(red) lw(1)) ///
	   (scatteri 0 `efff_lb'  0.4 `efff_lb', recast(line) lpattern(dash) color(red) lw(0.5)) ///
	   (scatteri 0 `efff_ub'  0.4 `efff_ub', recast(line) lpattern(dash) color(red) lw(0.5)), ///
	   xtitle("Estimated coefficient") ytitle("Fraction") legend(order(1 "Four" 2 "Three" 3 "Two" 4 "One") subtitle("Number of excluded comarcas") position(6) rows(1)) 
graph export output/fig_rep/leavecomarcasout.png, as(png) replace
