clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Robustness without day and hour restrictions
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

///Robustness, by day
mat treat = J(9,4,1)

forval yy = 1/9 {
areg rel_catesp estatut $controls [pw= POND_GEO ] if time<=`yy', absorb(COMARCA) cluster(PROVItime)

local pos = `yy' 
mat treat[`pos',1] = `yy'
mat treat[`pos',2] = _b[estatut]
mat treat[`pos',3] = _b[estatut] + _se[estatut]*invttail(e(N),0.05)
mat treat[`pos',4] = _b[estatut] - _se[estatut]*invttail(e(N),0.05)
}

g yyy = treat[_n,1] in 1/8
g efff = treat[_n,2] in 1/8
g efff_10 = treat[_n,3] in 1/8
g efff_90 = treat[_n,4] in 1/8

label var efff "Coefficient"
label var efff_10 "Lower bound CI 10"
label var efff_90 "Higher bound CI 90"

sort time

twoway (rcap efff_10 efff_90 yyy, yaxis(1) ytitle("Coefficient")) (scatter efff yyy,  yaxis(1) xlabel(1(1)9) xtitle("Days after the Ruling used in sample")  title("Effect of Ruling on support for more autonomy") legend(position(6) rows(1)))
graph export output/fig_rep/figure_rob_time.png, as(png) replace

///Robustness, by hour
drop efff_10 efff_90 efff yyy
mat treat = J(4,4,1)


forval yy = 19/22 {
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<`yy', absorb(COMARCA) cluster(PROVItime)

local pos = `yy' -18
mat treat[`pos',1] = `yy'
mat treat[`pos',2] = _b[estatut]
mat treat[`pos',3] = _b[estatut] + _se[estatut]*invttail(e(N),0.05)
mat treat[`pos',4] = _b[estatut] - _se[estatut]*invttail(e(N),0.05)
}

g yyy = treat[_n,1] in 1/4
g efff = treat[_n,2] in 1/4
g efff_10 = treat[_n,3] in 1/4
g efff_90 = treat[_n,4] in 1/4

label var efff "Coefficient"
label var efff_10 "Lower bound CI 10"
label var efff_90 "Higher bound CI 90"

sort time

twoway (rcap efff_10 efff_90 yyy, yaxis(1) ytitle("Coefficient")) (scatter efff yyy,  yaxis(1) xlabel(19(1)22) xtitle("Limit hour of interview used in sample")  title("Effect of Ruling on support for more autonomy") legend(position(6) rows(1)))
graph export output/fig_rep/figure_rob_hour.png, as(png) replace