clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Non-response bias
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Non-responses variables
gen noansw_rel=(P28>=98)
gen noansw_feel=(P25>=98)
gen noansw_probl=(p1_9600_R!=. | p1_9500_R!=. | p1_9800_R!=. | p1_9900_R!=.)
gen noansw_trib=(P20A>=98)
gen noansw_part=(P20B>=98)
gen noansw_govesp=(P20D>=98)
gen noansw_govcat=(P20F>=98)
gen noansw_parlesp=(P20G>=98)
gen noansw_parlcat=(P20H>=98)
gen noansw_tr=(P20A>=98 | P20B>=98 | P20D>=98 | P20F>=98 | P20G>=98 | P20H>=98)
gen noansw_tr_other=(P20B>=98 | P20D>=98 | P20F>=98 | P20G>=98 | P20H>=98)
gen noansw_partvot=(P32>90)
gen noansw_partvot_old=(P30>90)
gen noansw_prox_erc=(P22C>=98)
gen noansw_prox_ciu=(P22B>=98)
gen noansw_vot=(P30>90 | P32>90 | P22A>=98 | P22B>=98 | P22C>=98 | P22D>=98 | P22E>=98 | P22F>=98)

***Coefficient plot
matrix coeff = J(1,7,.)
matrix colnames coeff = "More autonomy" "Feeling Catalan" Problems Trust "Trust courts" "Trust others" Voting
matrix CI = J(2,7,.)
matrix colnames CI = noansw_rel noansw_feel noansw_probl noansw_tr noansw_trib noansw_tr_other noansw_vot
matrix rownames CI = ll95 ul95
local i = 0

foreach var of varlist noansw_rel noansw_feel noansw_probl noansw_tr noansw_trib noansw_tr_other noansw_vot{
local i=`i'+1
areg `var' estatut  [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
mat coeff[1,`i'] = _b[estatut]
mat CI[1,`i'] = _b[estatut] + _se[estatut]*invttail(e(N),0.05)
mat CI[2,`i'] = _b[estatut] - _se[estatut]*invttail(e(N),0.05)'
}

coefplot matrix(coeff), ci(CI) xline(0) title(Effect of the Ruling on non-responses)
graph export output/fig_rep/figure_cplot_noansw.png, as(png) replace