clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Persistence: independence
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

drop if wave!=3

drop entr_cat

append using data/final/data_ceo_2006_2013.dta

drop if ANY>2012

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edad_* mun_*

gen est_trabajo_ca=estatut*trabajo_cat
label var est_trabajo_ca "Ruling x speak catalan at work"

global inter est_nac*_esp est_nac*_for est_*_ca est_female est_edad_* est_casado ///
			 est_educ* est_ingr* est_empleo*
	
probit indep $controls i.COMARCA [pw= POND_GEO ] if estatut==0 & hoursurvey==0

predict pred_indep

areg indep estatut $controls $inter [pw= POND_GEO ] if HOR_INI<19 & time<7 & hoursurvey==. & wave==3, absorb(COMARCA) cluster(PROVItime)

gen me_est=_b[estatut]+ ///
		   _b[est_nac_esp]*nac_esp+_b[est_nac_for]*nac_for+ ///
		   _b[est_nac_padre_esp]*nac_padre_esp+_b[est_nac_padre_for]*nac_padre_for+ ///
		   _b[est_nac_madre_esp]*nac_madre_esp+_b[est_nac_madre_for]*nac_madre_for+ ///
		   _b[est_casa_ca]*casa_cat+_b[est_amigos_ca]*amigos_cat+_b[est_trabajo_ca]*trabajo_cat+  ///
		   _b[est_female]*female+_b[est_casado]*casado+ ///
		   _b[est_edad_3549]*edad_3549+_b[est_edad_5064]*edad_5064+_b[est_edad_64]*edad_64+ ///
		   _b[est_educ_eso]*educ_eso+_b[est_educ_bach]*educ_bach+_b[est_educ_uni]*educ_uni+ ///
		   _b[est_ingr_1001_2000]*ingr_1001_2000+_b[est_ingr_2001_3000]*ingr_2001_3000+_b[est_ingr_3001]*ingr_3001+ ///
		   _b[est_empleo_aut]*empleo_aut+_b[est_empleo_dep]*empleo_dep

gen elast_est=me_est/pred_indep

mat treat_m = J(9,4,1)
mat treat_m[1,1] = 1
mat treat_m[1,2] = 0
mat treat_m[1,3] = 0
mat treat_m[1,4] = 0
mat treat_p10 = J(9,4,1)
mat treat_p10[1,1] = 1
mat treat_p10[1,2] = 0
mat treat_p10[1,3] = 0
mat treat_p10[1,4] = 0
mat treat_p90 = J(9,4,1)
mat treat_p90[1,1] = 1
mat treat_p90[1,2] = 0
mat treat_p90[1,3] = 0
mat treat_p90[1,4] = 0

gen estbop=0 if BOP_NUM<21
replace estbop=BOP_NUM if BOP_NUM>=21
label define estbopl 0 "Pre-2009" 21 "June-10" 22 "Oct-10" 23 "Jan-11" ///
				   24 "June-11" 25 "Oct-11" 26 "Feb-12" 27 "June-12" 28 "Oct-12"
label values estbop estbopl

reg indep i.estbop##c.me_est if hoursurvey==0, rob
margins, dydx(estbop) at((mean) me_est)
matrix define table = r(table)
nlcom (diff_june1011: _b[21.estbop] - _b[24.estbop])
mat bbb=r(b)
mat vvv=r(V)
local bbb_indep=bbb[1,1]
local bbb_indep=trim("`: display %10.4f `bbb_indep''")
local sss_indep=(vvv[1,1])^(0.5)
local sss_indep=trim("`: display %10.4f `sss_indep''")

forvalues i=2/9{
mat treat_m[`i',1]=`i'
mat treat_m[`i',2]=table[1,`i']
mat treat_m[`i',3]=table[5,`i']
mat treat_m[`i',4]=table[6,`i']
}

margins, dydx(estbop) at((p10) me_est)
matrix define table = r(table)
forvalues i=2/9{
mat treat_p10[`i',1]=`i'+0.1
mat treat_p10[`i',2]=table[1,`i']
mat treat_p10[`i',3]=table[5,`i']
mat treat_p10[`i',4]=table[6,`i']
}
margins, dydx(estbop) at((p90) me_est)
matrix define table = r(table)
forvalues i=2/9{
mat treat_p90[`i',1]=`i'+0.2
mat treat_p90[`i',2]=table[1,`i']
mat treat_p90[`i',3]=table[5,`i']
mat treat_p90[`i',4]=table[6,`i']
}

g yy_m = treat_m[_n,1] in 1/9
g eff_m = treat_m[_n,2] in 1/9
g eff_m_5 = treat_m[_n,3] in 1/9
g eff_m_95 = treat_m[_n,4] in 1/9
g yy_p10 = treat_p10[_n,1] in 1/9
g eff_p10 = treat_p10[_n,2] in 1/9
g eff_p10_5 = treat_p10[_n,3] in 1/9
g eff_p10_95 = treat_p10[_n,4] in 1/9
g yy_p90 = treat_p90[_n,1] in 1/9
g eff_p90 = treat_p90[_n,2] in 1/9
g eff_p90_5 = treat_p90[_n,3] in 1/9
g eff_p90_95 = treat_p90[_n,4] in 1/9

label define yy_ml 1 "Pre-2010" 2 "June-10" 3 "Oct-10" 4 "Jan-11" ///
				   5 "June-11" 6 "Oct-11" 7 "Feb-12" 8 "June-12" 9 "Oct-12"
label values yy_m yy_ml  

label var eff_m "Marginal effect (at mean)"
label var eff_m_5 "L.b. CI"
label var eff_m_95 "H.b. CI 95 (at mean)"
label var eff_p10 "Marginal effect (at p10)"
label var eff_p10_5 "L.b. CI"
label var eff_p10_95 "H.b. CI 95 (at p10)"
label var eff_p90 "Marginal effect (at p90)"
label var eff_p90_5 "L.b. CI"
label var eff_p90_95 "H.b. CI 95 (at p90)"

twoway (rcap eff_m_5 eff_m_95 yy_m, title("Marginal effect survey wave on support for independence") ytitle("Coefficient")) (rcap eff_p10_5 eff_p10_95 yy_p10) (rcap eff_p90_5 eff_p90_95 yy_p90) (scatter eff_m yy_m, msymbol(o) xlabel(1 "Pre-2010" 2 "June-10" 3 "Oct-10" 4 "Jan-11"  5 "June-11" 6 "Oct-11" 7 "Feb-12" 8 "June-12" 9 "Oct-12") xtitle("Survey wave") caption(Test equality June10-June11: coefficient `bbb_indep' s.e. `sss_indep') legend(position(6) rows(2))) (scatter eff_p10 yy_p10, msymbol(D)) (scatter eff_p90 yy_p90, msymbol(T)) 
graph export output/fig_rep/figure_pers_survey_indep.png, as(png) replace

*******************************************************************************
***Persistence: trust courst
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

drop if wave!=3

drop entr_cat

append using data/final/data_ceo_2006_2013.dta

drop if ANY>2012

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edad_* mun_*

gen est_trabajo_ca=estatut*trabajo_cat
label var est_trabajo_ca "Ruling x speak catalan at work"

global inter est_nac*_esp est_nac*_for est_*_ca est_female est_edad_* est_casado ///
			 est_educ* est_ingr* est_empleo*
	
probit trust_trib $controls i.COMARCA [pw= POND_GEO ] if estatut==0 & hoursurvey==0

predict pred_trib

areg trust_trib estatut $controls $inter [pw= POND_GEO ] if HOR_INI<19 & time<7 & hoursurvey==. & wave==3, absorb(COMARCA) cluster(PROVItime)

gen me_est=_b[estatut]+ ///
		   _b[est_nac_esp]*nac_esp+_b[est_nac_for]*nac_for+ ///
		   _b[est_nac_padre_esp]*nac_padre_esp+_b[est_nac_padre_for]*nac_padre_for+ ///
		   _b[est_nac_madre_esp]*nac_madre_esp+_b[est_nac_madre_for]*nac_madre_for+ ///
		   _b[est_casa_ca]*casa_cat+_b[est_amigos_ca]*amigos_cat+_b[est_trabajo_ca]*trabajo_cat+  ///
		   _b[est_female]*female+_b[est_casado]*casado+ ///
		   _b[est_edad_3549]*edad_3549+_b[est_edad_5064]*edad_5064+_b[est_edad_64]*edad_64+ ///
		   _b[est_educ_eso]*educ_eso+_b[est_educ_bach]*educ_bach+_b[est_educ_uni]*educ_uni+ ///
		   _b[est_ingr_1001_2000]*ingr_1001_2000+_b[est_ingr_2001_3000]*ingr_2001_3000+_b[est_ingr_3001]*ingr_3001+ ///
		   _b[est_empleo_aut]*empleo_aut+_b[est_empleo_dep]*empleo_dep

gen elast_est=me_est/pred_trib

mat treat_m = J(3,4,1)
mat treat_m[1,1] = 1
mat treat_m[1,2] = 0
mat treat_m[1,3] = 0
mat treat_m[1,4] = 0
mat treat_p10 = J(3,4,1)
mat treat_p10[1,1] = 1
mat treat_p10[1,2] = 0
mat treat_p10[1,3] = 0
mat treat_p10[1,4] = 0
mat treat_p90 = J(3,4,1)
mat treat_p90[1,1] = 1
mat treat_p90[1,2] = 0
mat treat_p90[1,3] = 0
mat treat_p90[1,4] = 0

gen estbop=0 if BOP_NUM<21
replace estbop=BOP_NUM if BOP_NUM>=21
label define estbopl 0 "Pre-2009" 21 "June-10" 28 "Oct-12"
label values estbop estbopl

reg trust_trib i.estbop##c.me_est if hoursurvey==0, rob
margins, dydx(estbop) at((mean) me_est)
matrix define table = r(table)
nlcom (diff_june10oct12: _b[21.estbop] - _b[28.estbop])
mat bbb=r(b)
mat vvv=r(V)
local bbb_indep=bbb[1,1]
local bbb_indep=trim("`: display %10.4f `bbb_indep''")
local sss_indep=(vvv[1,1])^(0.5)
local sss_indep=trim("`: display %10.4f `sss_indep''")

forvalues i=2/3{
mat treat_m[`i',1]=`i'
mat treat_m[`i',2]=table[1,`i']
mat treat_m[`i',3]=table[5,`i']
mat treat_m[`i',4]=table[6,`i']
}

margins, dydx(estbop) at((p10) me_est)
matrix define table = r(table)
forvalues i=2/3{
mat treat_p10[`i',1]=`i'+0.1
mat treat_p10[`i',2]=table[1,`i']
mat treat_p10[`i',3]=table[5,`i']
mat treat_p10[`i',4]=table[6,`i']
}
margins, dydx(estbop) at((p90) me_est)
matrix define table = r(table)
forvalues i=2/3{
mat treat_p90[`i',1]=`i'+0.2
mat treat_p90[`i',2]=table[1,`i']
mat treat_p90[`i',3]=table[5,`i']
mat treat_p90[`i',4]=table[6,`i']
}

g yy_m = treat_m[_n,1] in 1/3
g eff_m = treat_m[_n,2] in 1/3
g eff_m_5 = treat_m[_n,3] in 1/3
g eff_m_95 = treat_m[_n,4] in 1/3
g yy_p10 = treat_p10[_n,1] in 1/3
g eff_p10 = treat_p10[_n,2] in 1/3
g eff_p10_5 = treat_p10[_n,3] in 1/3
g eff_p10_95 = treat_p10[_n,4] in 1/3
g yy_p90 = treat_p90[_n,1] in 1/3
g eff_p90 = treat_p90[_n,2] in 1/3
g eff_p90_5 = treat_p90[_n,3] in 1/3
g eff_p90_95 = treat_p90[_n,4] in 1/3

label define yy_ml 1 "Pre-2010" 2 "June-10" 3 "Oct-12"
label values yy_m yy_ml  

label var eff_m "Marginal effect (at mean)"
label var eff_m_5 "L.b. CI"
label var eff_m_95 "H.b. CI 95 (at mean)"
label var eff_p10 "Marginal effect (at p10)"
label var eff_p10_5 "L.b. CI"
label var eff_p10_95 "H.b. CI 95 (at p10)"
label var eff_p90 "Marginal effect (at p90)"
label var eff_p90_5 "L.b. CI"
label var eff_p90_95 "H.b. CI 95 (at p90)"

twoway (rcap eff_m_5 eff_m_95 yy_m, title("Marginal effect survey wave on trust in courts") ytitle("Coefficient")) (rcap eff_p10_5 eff_p10_95 yy_p10) (rcap eff_p90_5 eff_p90_95 yy_p90) (scatter eff_m yy_m, msymbol(o) xlabel(1 "Pre-2010" 2 "June-10" 3  "Oct-12") xtitle("Survey wave") caption(Test equality June10-Oct12: coefficient `bbb_indep' s.e. `sss_indep') legend(position(6) rows(2))) (scatter eff_p10 yy_p10, msymbol(D)) (scatter eff_p90 yy_p90, msymbol(T)) 
graph export output/fig_rep/figure_pers_survey_trib.png, as(png) replace