clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***W3-2010
*******************************************************************************
*******************************************************************************
***Prediction: W3-2010
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Generate interactions between province and dummy for size cities
egen provimun=group(PROVI HABITAT)
tab provimun if PROVI==1 & HABITAT==6
replace provimun=0 if provimun==6
replace provimun=provimun-1 if provimun>6
tabulate provimun, gen(provimun_d)
foreach var of varlist provimun_d*{
gen est_`var'=estatut*`var'
}
drop est_provimun_d1 provimun_d1

***Estimate independence equation with province-size heterogeneities
label var est_provimun_d2 "Ruling x BCN less 2k inh."
label var est_provimun_d3 "Ruling x BCN 2k-10k inh."
label var est_provimun_d4 "Ruling x BCN 10k-50k inh."
label var est_provimun_d5 "Ruling x BCN 50-150k inh."
label var est_provimun_d6 "Ruling x BCN 150k-1mil inh."
label var est_provimun_d7 "Ruling x GIR less 2k inh."
label var est_provimun_d8 "Ruling x GIR 2k-10k inh."
label var est_provimun_d9 "Ruling x GIR 10k-50k inh."
label var est_provimun_d10 "Ruling x GIR 50k-150k inh."
label var est_provimun_d11 "Ruling x LLE less 2k inh."
label var est_provimun_d12 "Ruling x LLE 2k-10k inh."
label var est_provimun_d13 "Ruling x LLE 10k-50k inh."
label var est_provimun_d14 "Ruling x LLE 50k-150k inh."
label var est_provimun_d15 "Ruling x TAR less 2k inh."
label var est_provimun_d16 "Ruling x TAR 2k-10k inh."
label var est_provimun_d17 "Ruling x TAR 10k-50k inh."
label var est_provimun_d18 "Ruling x TAR 50k-150k inh."

reg indep estatut est_provimun_d* provimun_d* $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, cluster(PROVItime)
 
*Predict marginal effect ruling
gen me_est=_b[estatut]+ ///
		   _b[est_provimun_d2]*provimun_d2+_b[est_provimun_d3]*provimun_d3+ ///
		   _b[est_provimun_d4]*provimun_d4+_b[est_provimun_d5]*provimun_d5+ ///
		   _b[est_provimun_d5]*provimun_d6+_b[est_provimun_d7]*provimun_d7+ ///
		   _b[est_provimun_d6]*provimun_d8+_b[est_provimun_d9]*provimun_d9+ ///
		   _b[est_provimun_d10]*provimun_d10+_b[est_provimun_d11]*provimun_d11+ ///
		   _b[est_provimun_d12]*provimun_d12+_b[est_provimun_d13]*provimun_d13+ ///
		   _b[est_provimun_d14]*provimun_d14+_b[est_provimun_d15]*provimun_d15+ ///
		   _b[est_provimun_d16]*provimun_d16+_b[est_provimun_d17]*provimun_d17+ ///
		   _b[est_provimun_d18]*provimun_d18
		   
		   
predict pred_estatut, xb

drop if estatut==0

***Join with voting data		   
collapse (mean) me_est pred_estatut (first) PROVI HABITAT, by(provimun)
*PROVI: 1: BCN, 2: GIR, 3: LLE, 4: TAR
*HABITAT: 1: <2k, 2: 2k-10k, 3: 10k-50k, 4: 50k-150k, 5: 150k-1m, 6:1m+

tempfile t1
save `t1'

*******************************************************************************
***Voting data
*******************************************************************************
use data/final/data_autonomiques.dta, clear
gen PROVI=1 if nprov=="Barcelona"
replace PROVI=2 if nprov=="Girona"
replace PROVI=3 if nprov=="Lleida"
replace PROVI=4 if nprov=="Tarragona"

gen pob_2010_2=pob if t_loc==2010
egen pob_2010=max(pob_2010_2) ,by(codiine)
drop pob_2010_2

gen HABITAT=1 if pob_2010<=2000
replace HABITAT=2 if pob_2010>=2001 & pob_2010<=10000
replace HABITAT=3 if pob_2010>=10001 & pob_2010<=50000
replace HABITAT=4 if pob_2010>=50001 & pob_2010<=150000
replace HABITAT=5 if pob_2010>=150001 & pob_2010<=1000000
replace HABITAT=6 if pob_2010>=1000001

*******************************************************************************
***Merge and cleaning: W3-2010 for prediction
*******************************************************************************
merge m:1 PROVI HABITAT using `t1'

drop if _merge!=3
drop _merge

gen name = lower(ustrto(ustrnormalize(npartit_loc, "nfd"), "ascii", 2))
gen junts=(name=="junts pel si")

gen ri=(name=="reagrupament independentista")
gen si=(name=="solidaritat catalana per la independencia")
gen risi=(name=="reagrupament independentista" | name=="solidaritat catalana per la independencia")
gen cup=(name=="candidatura d'unitat popular-alternativa d'esquerres" | name=="candidatura d'unitat popular")
gen ercciujunts=(iloc==4 | iloc==8 | junts==1)
gen allindep=(iloc==4 | iloc==8 | junts==1 | cup==1)

gen share_c=vloc/cens
gen share_v=vloc/votants
gen turnout=votants/cens

gen share_v_erc=share_v if iloc==8
gen share_v_ciu=share_v if iloc==4
egen share_v_ercciu=total(share_v) if iloc==4 | iloc==8,by(codiin t_loc)
gen share_v_ercciujunts=share_v_ercciu
replace share_v_ercciujunts=share_v if junts==1
egen share_v_allindep = total(share_v) if junts==1| iloc==4 | iloc==8 | risi==1 | cup==1,by(codiin t_loc)
egen share_v_risi = total(share_v) if risi==1,by(codiin t_loc)

***Treatment variables
*Share ERC in 1999
gen share_v_erc_99_2=share_v_erc if t_loc==1999
egen share_v_erc_99=max(share_v_erc_99_2), by(codiine)
drop share_v_erc_99_2
sum share_v_erc_99, det
gen share_v_erc_99_moremed=(share_v_erc_99>=`r(p50)')

label var share_v_erc_99 "Vote share ERC 1999"

*D-D variables
gen post2010=(t_loc>=2010)
gen post2010me_est=post2010*me_est
gen post2003=(t_loc>=2003)
gen post2003me_est=post2003*me_est
gen post2006=(t_loc>=2006)
gen post2006me_est=post2006*me_est

label var post2010 "Post 2010"
label var post2010me_est "Post 2010 X M.E. Ruling"
label var post2003 "Post 2003"
label var post2003me_est "Post 2003 X M.E. Ruling"
label var post2006 "Post 2006"
label var post2006me_est "Post 2006 X M.E. Ruling"

gen post2010me_est_erc_moremed=post2010*me_est*share_v_erc_99_moremed
gen post2010me_est_erc_1=post2010*me_est*share_v_erc_99
gen post2010me_est_erc_2=post2010*me_est*share_v_erc_99*share_v_erc_99

label var post2010me_est_erc_moremed "Post 2010 X M.E. Ruling x ERC 1999 ($>$ med.)"
label var post2010me_est_erc_1 "Post 2010 X M.E. Ruling x ERC 1999"
label var post2010me_est_erc_2 "Post 2010 X M.E. Ruling x ERC 1999 (sq.)"
