clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

////////////////////////////////////////////////
///Polarization all parties
////////////////////////////////////////////////
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

gen psc_old=(P30==4)
replace psc_old=. if P30>90

gen icv_old=(P30==5)
replace icv_old=. if P30>90

foreach var of varlist *_old{
replace `var'=. if P30>=6
}

drop est_ciu_old est_erc_old
foreach var of varlist ciu_old erc_old psc_old icv_old{
gen est_`var'=estatut*`var'
}

label var ppc_old "Past vote PPC"
label var ciu_old "Past vote CiU"
label var erc_old "Past vote ERC"
label var psc_old "Past vote PSC"
label var icv_old "Past vote ICV"
label var est_ciu_old "Ruling X Past vote CiU"
label var est_erc_old "Ruling X Past vote ERC"
label var est_psc_old "Ruling X Past vote PSC"
label var est_icv_old "Ruling X Past vote ICV"
label var est_ppc_old "Ruling X Past vote PPC"

label var ppc_old_all "Past vote PPC"
label var est_ppc_old_all "Ruling X Past vote PPC"

***Polariz all parties, cplot
*CiU
matrix coeff_ciu = J(1,4,.)
matrix colnames coeff_ciu = "Region (less autonomy)" "Autonomous comm. (status quo)" "Federal state (more autonomy)" "Independence (full autonomy)" 
matrix CI_ciu = J(2,4,.)
matrix colnames CI_ciu = regio ccaa estadofed indep
matrix rownames CI_ciu = ll95 ul95
local i = 0

oprobit rel_catesp estatut##ciu_old estatut##erc_old estatut##psc_old estatut##icv_old $controls i.COMARCA [pw= POND_GEO ] if HOR_INI<19 & time<7,  cluster(PROVItime)
margins, dydx(estatut) at(ciu_old==1)
mat b = r(b)
forvalues i=1/4{
local j=`i'+4
mat coeff_ciu[1,`i']=b[1,`j']
mat v = r(table)
mat CI_ciu[1,`i']=b[1,`j'] + v[2,`j']*invttail(e(N),0.05)
mat CI_ciu[2,`i']=b[1,`j'] - v[2,`j']*invttail(e(N),0.05)
}

*ERC
matrix coeff_erc = J(1,4,.)
matrix colnames coeff_erc = "Region (less autonomy)" "Autonomous comm. (status quo)" "Federal state (more autonomy)" "Independence (full autonomy)" 
matrix CI_erc = J(2,4,.)
matrix colnames CI_erc = regio ccaa estadofed indep
matrix rownames CI_erc = ll95 ul95
local i = 0

oprobit rel_catesp estatut##ciu_old estatut##erc_old estatut##psc_old estatut##icv_old $controls i.COMARCA [pw= POND_GEO ] if HOR_INI<19 & time<7,  cluster(PROVItime)
margins, dydx(estatut) at(erc_old==1)
mat b = r(b)
forvalues i=1/4{
local j=`i'+4
mat coeff_erc[1,`i']=b[1,`j']
mat v = r(table)
mat CI_erc[1,`i']=b[1,`j'] + v[2,`j']*invttail(e(N),0.05)
mat CI_erc[2,`i']=b[1,`j'] - v[2,`j']*invttail(e(N),0.05)
}

*PSC
matrix coeff_psc = J(1,4,.)
matrix colnames coeff_psc = "Region (less autonomy)" "Autonomous comm. (status quo)" "Federal state (more autonomy)" "Independence (full autonomy)" 
matrix CI_psc = J(2,4,.)
matrix colnames CI_psc = regio ccaa estadofed indep
matrix rownames CI_psc = ll95 ul95
local i = 0

oprobit rel_catesp estatut##ciu_old estatut##erc_old estatut##psc_old estatut##icv_old $controls i.COMARCA [pw= POND_GEO ] if HOR_INI<19 & time<7,  cluster(PROVItime)
margins, dydx(estatut) at(psc_old==1)
mat b = r(b)
forvalues i=1/4{
local j=`i'+4
mat coeff_psc[1,`i']=b[1,`j']
mat v = r(table)
mat CI_psc[1,`i']=b[1,`j'] + v[2,`j']*invttail(e(N),0.05)
mat CI_psc[2,`i']=b[1,`j'] - v[2,`j']*invttail(e(N),0.05)
}

*ICV
matrix coeff_icv = J(1,4,.)
matrix colnames coeff_icv = "Region (less autonomy)" "Autonomous comm. (status quo)" "Federal state (more autonomy)" "Independence (full autonomy)" 
matrix CI_icv = J(2,4,.)
matrix colnames CI_icv = regio ccaa estadofed indep
matrix rownames CI_icv = ll95 ul95
local i = 0

oprobit rel_catesp estatut##ciu_old estatut##erc_old estatut##psc_old estatut##icv_old $controls i.COMARCA [pw= POND_GEO ] if HOR_INI<19 & time<7,  cluster(PROVItime)
margins, dydx(estatut) at(icv_old==1)
mat b = r(b)
forvalues i=1/4{
local j=`i'+4
mat coeff_icv[1,`i']=b[1,`j']
mat v = r(table)
mat CI_icv[1,`i']=b[1,`j'] + v[2,`j']*invttail(e(N),0.05)
mat CI_icv[2,`i']=b[1,`j'] - v[2,`j']*invttail(e(N),0.05)
}

*PPC
matrix coeff_ppc = J(1,4,.)
matrix colnames coeff_ppc = "Region (less autonomy)" "Autonomous comm. (status quo)" "Federal state (more autonomy)" "Independence (full autonomy)" 
matrix CI_ppc = J(2,4,.)
matrix colnames CI_ppc = regio ccaa estadofed indep
matrix rownames CI_ppc = ll95 ul95
local i = 0

oprobit rel_catesp estatut##ciu_old estatut##erc_old estatut##psc_old estatut##icv_old $controls i.COMARCA [pw= POND_GEO ] if HOR_INI<19 & time<7,  cluster(PROVItime)
margins, dydx(estatut) at(icv_old==0 psc_old==0 erc_old==0 ciu_old==0)
mat b = r(b)
forvalues i=1/4{
local j=`i'+4
mat coeff_ppc[1,`i']=b[1,`j']
mat v = r(table)
mat CI_ppc[1,`i']=b[1,`j'] + v[2,`j']*invttail(e(N),0.05)
mat CI_ppc[2,`i']=b[1,`j'] - v[2,`j']*invttail(e(N),0.05)
}

*Graph
coefplot (matrix(coeff_ppc), ci(CI_ppc) label(PPC voters) xline(0) title(Effect of the Ruling) legend(position(6) rows(1)) msymbol(o))  (matrix(coeff_psc), ci(CI_psc) label(PSC voters) msymbol(D)) (matrix(coeff_ciu), ci(CI_ciu) label(CiU voters) msymbol(T)) (matrix(coeff_erc), ci(CI_erc) label(ERC voters) msymbol(S))  (matrix(coeff_icv), ci(CI_icv) label(ICV voters) msymbol(X)) 
graph export output/fig_rep/figure_cplot_polariz_parties.png, as(png) replace