clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Within-Catalonia: TV3 and internet consumption
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

gen est_internet=estatut*P16_INTERNET_U
gen est_amigos=estatut*P16_AMICS_U

label var P16_INTERNET_U "Internet for information"
label var est_internet "Ruling x Internet for information"
label var P16_AMICS_U "Friends for information"
label var est_amigos "Ruling x Friends for information"
label var tv3 "TV3"

*TV3: endogeneity
eststo a: areg tv3 estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
*TV3: heterogeneity
eststo b: areg rel_catesp estatut tv3 est_tv3 $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
*Internet use: heterogeneity
eststo c: areg rel_catesp estatut P16_INTERNET_U est_internet $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
*Friends: heterogeneity
eststo d: areg rel_catesp estatut P16_AMICS_U est_amigos $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)

esttab a b c d using output/tab_rep/table_tv3.tex, eqlabel(none) nonumbers nonotes se label ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(estatut tv3 est_tv3 P16_INTERNET_U est_internet P16_AMICS_U est_amigos) ///
mtitles("(1)" "(2)" "(3)" "(4)") ///
mgroups("\makecell{TV3}" "\makecell{More autonomy}", ///
pattern(1 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
scalars("sta R-squared") ///
compress replace