clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Placebo: different periods same wave
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Placebo variables
sort time HOR_INI MIN_INI SEG_INI
egen id_hor=seq() if HOR_INI<19

gen order_hor227=1 if id_hor<=227
forvalues i=2/7{
replace order_hor227=`i' if id_hor>227*(`i'-1) & id_hor<=227*`i'
}

forvalues i=1/7{
local j=`i'
gen order_hor227_`j'=(order_hor227==`i')
}

label var order_hor227_2 "Placebo: 2nd 227 obs W3-2010"
label var order_hor227_3 "Placebo: 3rd 227 obs W3-2010"
label var order_hor227_4 "Placebo: 4th 227 obs W3-2010"
label var order_hor227_5 "Placebo: 5th 227 obs W3-2010"
label var order_hor227_6 "Placebo: 6th 227 obs W3-2010"
label var order_hor227_7 "Placebo: 7th 227 obs W3-2010"

***Regressions
*2nd 227 observations
eststo a: areg indep order_hor227_2 $controls [pw= POND_GEO ] if order_hor227!=1 & HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W3-2010"
*3rd
eststo b: areg indep order_hor227_3 $controls [pw= POND_GEO ] if order_hor227!=1 & HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W3-2010"
*4th
eststo c: areg indep order_hor227_4 $controls [pw= POND_GEO ] if order_hor227!=1 & HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W3-2010"
*5th
eststo d: areg indep order_hor227_5 $controls [pw= POND_GEO ] if order_hor227!=1 & HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W3-2010"
*6th
eststo e: areg indep order_hor227_6 $controls [pw= POND_GEO ] if order_hor227!=1 & HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W3-2010"
*7th
eststo f: areg indep order_hor227_7 $controls [pw= POND_GEO ] if order_hor227!=1 & HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W3-2010"

*******************************************************************************
***Placebo:same periods different wave
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*


***Placebo variables
gen DIA16=(DIA!=16)
label var DIA16 "Placebo: 1st day W2-2010"
gen DIA19=(DIA!=19)
label var DIA19 "Placebo: 1st Monday W2-2010"
gen DIA11=(DIA==11)
label var DIA11 "Placebo: 1st day (and Monday) W4-2010"

forvalues i=1/7{
local j=`i'
gen order_hor227_`j'=.
}

label var order_hor227_2 "Placebo: 2nd 227 obs W3-2010"
label var order_hor227_3 "Placebo: 3rd 227 obs W3-2010"
label var order_hor227_4 "Placebo: 4th 227 obs W3-2010"
label var order_hor227_5 "Placebo: 5th 227 obs W3-2010"
label var order_hor227_6 "Placebo: 6th 227 obs W3-2010"
label var order_hor227_7 "Placebo: 7th 227 obs W3-2010"

***Regressions
*1st day W2-2010
eststo g: areg indep DIA16 $controls [pw= POND_GEO ] if survey=="2-2010" & HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W2-2010"
*1st and monday W4-2010
eststo h: areg indep DIA11 $controls [pw= POND_GEO ] if survey=="4-2010" & HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W4-2010"
*1st monday W2-2010
eststo i: areg indep DIA19 $controls [pw= POND_GEO ] if survey=="2-2010" & HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W2-2010"

esttab a b c d e f g h i using output/tab_rep/table_pl_order.tex, eqlabel(none) nonumbers nonotes se label ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(order_hor227_2 order_hor227_3 order_hor227_4 order_hor227_5 order_hor227_6 order_hor227_7 DIA16 DIA11 DIA19) ///
mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)") ///
mgroups("\makecell{Independence}", ///
pattern(1 0 0 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
scalars("sta R-squared" "info_sam Sample") ///
compress replace