clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Robustness to small sample size
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="2-2010" | survey=="3-2010" 

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

gen sample=1 if survey=="2-2010" & HOR_INI<19
replace sample=1 if survey=="3-2010" & HOR_INI<19 & time<7

*Define sample
areg rel_catesp estatut $controls [pw= POND_GEO ] if  HOR_INI<19 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
gen SAMPLE=e(sample)
sort time HOR_INI MIN_INI
egen seq=seq() if survey=="3-2010" & SAMPLE==1

///Unbalancedness
areg rel_catesp estatut $controls [pw= POND_GEO ] if seq<=340 & SAMPLE==1 & HOR_INI<19 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
outreg2 using output/tab_rep/table_rob_unbalancedness, tex(frag) nocon noni nonotes label ctitle("More autonomy") keep(estatut) addtext(Sample, W3-2010, Restrictions, Balanced sample, Weights, Yes, Inference, cluster s.e.) replace
///Bigger control group
areg rel_catesp estatut $controls i.wave [pw= POND_GEO ] , absorb(COMARCA) cluster(PROVItime)
outreg2 using output/tab_rep/table_rob_unbalancedness, tex(frag) nocon noni nonotes label ctitle("More autonomy") keep(estatut) addtext(Sample, W2-W3-2010, Restrictions, No, Weights, Yes, Inference, cluster s.e.)
///Bigger control group (with hour restriction)
areg rel_catesp estatut $controls i.wave [pw= POND_GEO ] if HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
outreg2 using output/tab_rep/table_rob_unbalancedness, tex(frag) nocon noni nonotes label ctitle("More autonomy") keep(estatut) addtext(Sample, W2-W3-2010, Restrictions, Hours, Weights, Yes, Inference, cluster s.e.) 
///Randomization inference
ritest estatut _b[estatut], reps(1000) seed(125) strata(strata): areg rel_catesp estatut $controls if HOR_INI<19 & time<7 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
outreg2 using output/tab_rep/table_rob_unbalancedness, tex(frag) nocon noni nonotes label ctitle("More autonomy") keep(estatut) addtext(Sample, W3-2010, Restrictions, Hours and days, Weights, No, Inference, random. inf.) 
