clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Non-response bias
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Non-responses variables
gen noansw_rel=(P28>=98)
gen noansw_feel=(P25>=98)
gen noansw_probl=(p1_9600_R!=. | p1_9500_R!=. | p1_9800_R!=. | p1_9900_R!=.)
gen noansw_trib=(P20A>=98)
gen noansw_part=(P20B>=98)
gen noansw_govesp=(P20D>=98)
gen noansw_govcat=(P20F>=98)
gen noansw_parlesp=(P20G>=98)
gen noansw_parlcat=(P20H>=98)
gen noansw_tr=(P20A>=98 | P20B>=98 | P20D>=98 | P20F>=98 | P20G>=98 | P20H>=98)
gen noansw_tr_other=(P20B>=98 | P20D>=98 | P20F>=98 | P20G>=98 | P20H>=98)
gen noansw_partvot=(P32>90)
gen noansw_partvot_old=(P30>90)
gen noansw_prox_erc=(P22C>=98)
gen noansw_prox_ciu=(P22B>=98)
gen noansw_vot=(P30>90 | P32>90 | P22A>=98 | P22B>=98 | P22C>=98 | P22D>=98 | P22E>=98 | P22F>=98)

***Entrophy balancing, trust
*Baseline
ebalance estatut noansw_trib i.COMARCA , tar(1) g(ebw_trib)
gen ebw_geo=ebw_trib*POND_GEO
eststo a: areg trust_trib estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_con "Yes"
estadd local info_weight "p.w."
*Entrophy balancing, balancing
eststo b: reg noansw_trib estatut  [pweight=ebw_geo], cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "No"
estadd local info_con "No"
estadd local info_weight "e.b. x p.w."
*Entrophy balancing, effect
eststo c: reg trust_trib estatut $controls [pweight=ebw_geo],  cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "No"
estadd local info_con "No"
estadd local info_weight "e.b. x p.w."

esttab a b c using output/tab_rep/table_rob_trust.tex, eqlabel(none) nonumbers nonotes se label ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(estatut) ///
mtitles("(1)" "(2)" "(3)") ///
mgroups("\makecell{Trust courts}" "\makecell{Non-response on Trust courts}" "\makecell{Trust courts}", ///
pattern(1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
scalars("sta R-squared" "info_com Comarca FE" "info_con Controls" "info_weight Weights") ///
compress replace