clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Standard errors
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Cluster variables
egen COMARCAtime=group(COMARCA time)

***Regressions
*Robust
eststo a: areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) robust
estadd local info_cluster "Robust"
*Province x day
eststo b: areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd local info_cluster "Prov. x day"
*Day 
eststo c: areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(time)
estadd local info_cluster "Day"
*Comarca x day
eststo d: areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(COMARCAtime)
estadd local info_cluster "Comarca x day"
*Bootstrap
eststo e: bootstrap, reps(1000): areg rel_catesp estatut $controls if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd local info_cluster "Boot. prov. x day"
*Wild cluster bootstrap with multi-way clustered standard errors
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
boottest estatut, cluster(time PROVI) weight(webb)
local tt = string(round(`r(t)',0.01) , "%9.2f")
local pp = string(round(`r(p)',0.01) , "%9.2f")
estadd local info_tt "`tt'"
estadd local info_pp "`pp'"

eststo f: areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd local info_tt "`tt'"
estadd local info_pp "`pp'"
estadd local info_cluster "M.c. prov. day"

esttab a b c d e f using  output/tab_rep/table_rob_se.tex, eqlabel(none) nonumbers nonotes se label ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(estatut) ///
mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(6)") ///
mgroups("\makecell{More autonomy}", ///
pattern(1 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
scalars("info_cluster s.e." "info_tt t or z wild boot" "info_pp p-value wild boot") ///
compress replace