clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Multiple hypothesis testing
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Define p-value matrix 

mat def pvalue = J(14, 1, .)

///More autonomy (Table 2, column 2)
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[1,1]=r(p)
///Trust (Table 3)
*Courts
areg trust_trib estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[2,1]=r(p)
*Spanish government
areg trust_govesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[3,1]=r(p)
*Spanish parliament
areg trust_parlesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[4,1]=r(p)
*Catalan government
areg trust_govcat estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[5,1]=r(p)
*Catalan parliament
areg trust_parlcat estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[6,1]=r(p)
*Parties
areg trust_part estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[7,1]=r(p)
*Democracy
areg satisf_demo_poco estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[8,1]=r(p)

///Perceived problems (Table 4)
*Most: Cat-Esp
areg problmost_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[9,1]=r(p)
*Most: Estatut
areg problmostspec_estatut estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[10,1]=r(p)
*Most: Eco-lab
areg problmost_ecolab estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[11,1]=r(p)
*Most: Financing
areg problmost_financing estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[12,1]=r(p)

///Identity (Table A.6 column 1)
areg cat_feeling estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[13,1]=r(p)

///Voting (Table 7 column 1)
areg part_indep estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[14,1]=r(p)

***Correction
preserve
svmat pvalue 
gen outcome = _n

rename pvalue1 pval

include "code/analysis/appendix/tab/table_a23_aux_fdr_sharpened_qvalues.do"

keep bky06_qval
mkmat bky06_qval, mat(fdrpvals)
restore 

***Export results with unadjusted and adjusted p-values 

file open myfile using output/tab_rep/table_multhyptest.txt, write replace
file write myfile "\begin{tabular}{l c c c c c c c} \hline\hline  & (1) & (2) & (3) & (4) & (5) & (6) & (7)  \\  \multicolumn{8}{c}{Panel A: Preferred relationship between Spain and Catalonia, problems, identity and voting} \\ &  & \multicolumn{4}{c}{Most important problems} &  &   \\ \cline{3-6} \\  &  More & Catalonia- & Statute of & Economy \& & Catalan & Feeling & Cat parties  \\ & autonomy & Spain & autonomy & labour market & financing & Catalan & Future vote  \\ \hline " _n

*Panel A

///More autonomy 
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_1="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_1 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_1=string(round(fdrpvals[1,1],0.001) , "%9.3f")

///Perceived problems 
*Most: Cat-Esp
areg problmost_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_2="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_2 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_2=string(round(fdrpvals[9,1],0.001) , "%9.3f")


*Most: Estatut
areg problmostspec_estatut estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_3="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_3 = string(round(`pval_unadj',.001) , "%9.3f")
 
local pval_adj_3=string(round(fdrpvals[10,1],0.001) , "%9.3f")


*Most: Eco-lab
areg problmost_ecolab estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_4="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_4 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_4=string(round(fdrpvals[11,1],0.001) , "%9.3f")


*Most: Financing
areg problmost_financing estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_5="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_5 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_5=string(round(fdrpvals[12,1],0.001) , "%9.3f")


///Identity 
areg cat_feeling estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_6="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_6 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_6=string(round(fdrpvals[13,1],0.001) , "%9.3f")

///Voting 
areg part_indep estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_7="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_7 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_7=string(round(fdrpvals[14,1],0.001) , "%9.3f")

file write myfile ("Ruling") _tab  "&"   _tab %11.2f ("`b_1'") _tab "&"   _tab %11.2f ("`b_2'") _tab  "&"   _tab %11.2f ("`b_3'") _tab  "&"   _tab %11.2f ("`b_4'") _tab "&"   _tab %11.2f ("`b_5'") _tab "&"   _tab %11.2f ("`b_6'") _tab "&"   _tab %11.2f ("`b_7'") _tab "\\" _n

file write myfile  _tab  "&"   _tab %11.2f ("(`pval_unadj_1')") _tab "&"   _tab %11.2f ("(`pval_unadj_2')") _tab  "&"   _tab %11.2f ("(`pval_unadj_3')") _tab  "&"   _tab %11.2f ("(`pval_unadj_4')") _tab "&"   _tab %11.2f ("(`pval_unadj_5')") _tab "&"   _tab %11.2f ("(`pval_unadj_6')") _tab "&"   _tab %11.2f ("(`pval_unadj_7')") _tab "\\" _n

file write myfile  _tab  "&"   _tab %11.2f ("$\left[`pval_adj_1'\right]$") _tab "&"   _tab %11.2f ("$\left[`pval_adj_2'\right]$") _tab  "&"   _tab %11.2f ("$\left[`pval_adj_3'\right]$") _tab  "&"   _tab %11.2f ("$\left[`pval_adj_4'\right]$") _tab "&"   _tab %11.2f ("$\left[`pval_adj_5'\right]$") _tab "&"   _tab %11.2f ("$\left[`pval_adj_6'\right]$") _tab "&"   _tab %11.2f ("$\left[`pval_adj_7'\right]$") _tab "\\" _n

file write myfile "\hline \\"

*Panel B

file write myfile "\multicolumn{8}{c}{Panel B: Trust in democratic institutions} \\ &  Courts & Esp Gov't & Esp Parl. & Cat Gov't & Cat Parl. & Parties & Insatisf. democr.   \\ \hline " _n

///Trust 
*Courts
areg trust_trib estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_1="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_1 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_1=string(round(fdrpvals[2,1],0.001) , "%9.3f")

*Spanish government
areg trust_govesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_2="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_2 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_2=string(round(fdrpvals[3,1],0.001) , "%9.3f")

*Spanish parliament
areg trust_parlesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_3="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_3 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_3=string(round(fdrpvals[4,1],0.001) , "%9.3f")

*Catalan government
areg trust_govcat estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_4="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_4 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_4=string(round(fdrpvals[5,1],0.001) , "%9.3f")

*Catalan parlament
areg trust_parlcat estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_5="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_5 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_5=string(round(fdrpvals[6,1],0.001) , "%9.3f")

*Parties
areg trust_part estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_6="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_6 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_6=string(round(fdrpvals[7,1],0.001) , "%9.3f")

*Democracy
areg satisf_demo_poco estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)

local diff = _b[estatut]
    local pval = ttail(e(df_r),abs(_b[estatut]/_se[estatut]))*2
	if `pval'>0.1  {
		local b = string(`diff',"%8.3f") 
	} 
	else if `pval'>0.05 { 
		local b = string(`diff',"%8.3f") + "$^\star$"
	}
	else if `pval'>0.01 { 
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$"
	}
	else {
		local b = string(`diff',"%8.3f") + "$^\star$" + "$^\star$" + "$^\star$"
	}
local b_7="`b'"
	
matrix define ppp = r(table)
 local pval_unadj = ppp[4,1]
 local pval_unadj_7 = string(round(`pval_unadj',.001) , "%9.3f")

local pval_adj_7=string(round(fdrpvals[8,1],0.001) , "%9.3f")

file write myfile ("Ruling") _tab  "&"   _tab %11.2f ("`b_1'") _tab "&"   _tab %11.2f ("`b_2'") _tab  "&"   _tab %11.2f ("`b_3'") _tab  "&"   _tab %11.2f ("`b_4'") _tab "&"   _tab %11.2f ("`b_5'") _tab "&"   _tab %11.2f ("`b_6'") _tab "&"   _tab %11.2f ("`b_7'") _tab "\\" _n

file write myfile  _tab  "&"   _tab %11.2f ("(`pval_unadj_1')") _tab "&"   _tab %11.2f ("(`pval_unadj_2')") _tab  "&"   _tab %11.2f ("(`pval_unadj_3')") _tab  "&"   _tab %11.2f ("(`pval_unadj_4')") _tab "&"   _tab %11.2f ("(`pval_unadj_5')") _tab "&"   _tab %11.2f ("(`pval_unadj_6')") _tab "&"   _tab %11.2f ("(`pval_unadj_7')") _tab "\\" _n

file write myfile  _tab  "&"   _tab %11.2f ("$\left[`pval_adj_1'\right]$") _tab "&"   _tab %11.2f ("$\left[`pval_adj_2'\right]$") _tab  "&"   _tab %11.2f ("$\left[`pval_adj_3'\right]$") _tab  "&"   _tab %11.2f ("$\left[`pval_adj_4'\right]$") _tab "&"   _tab %11.2f ("$\left[`pval_adj_5'\right]$") _tab "&"   _tab %11.2f ("$\left[`pval_adj_6'\right]$") _tab "&"   _tab %11.2f ("$\left[`pval_adj_7'\right]$") _tab "\\" _n

file write myfile "\hline \end{tabular}"
file close myfile










