clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***World cup 2010 --- Robustness controlling
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

gen dayafter_match=(DIA==30 | DIA==4 | DIA==8)

label var dayafter_match "Day after WC match"

***Dropping day after WC
*More autonomy
eststo a: areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & dayafter_match!=1, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "No World Cup"
 
*Catalan feeling
eststo b: areg cat_feeling estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & dayafter_match!=1, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "No World Cup"

***Controlling for day after
*More autonomy
eststo c: areg rel_catesp estatut $controls dayafter_match [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W3-2010"
 
*Catalan feeling
eststo d: areg cat_feeling estatut $controls dayafter_match [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_sam "W3-2010"

esttab a b c d using output/tab_rep/table_rob_worldcup.tex, nonumbers nonotes se label ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(estatut dayafter_match) ///
mtitles("(1)" "(2)" "(3)" "(4)") ///
mgroups("\makecell{More \\ autonomy}" "\makecell{Feeling \\ Catalan}" ///
		"\makecell{More \\ autonomy}" "\makecell{Feeling \\ Catalan}", ///
pattern(1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
scalars("sta R-squared" "info_sam Sample") ///
compress replace