clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***World cup 2010 --- Effect victories on Catalan feeling
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

gen dayafter_match=(DIA==30 | DIA==4 | DIA==8)

label var dayafter_match "Day after WC match"

label var post_match_29_6_10 "Post-round of 16"
label var post_match_3_7_10 "Post-quarterfinal"

label var est_si_padres "Ruling x Catalan heritage"
label var dnac_padres_kat_ambos "Catalan heritage"

gen post_match_8_7_10=1 if DIA==8 & survey=="3-2010"
replace post_match_8_7_10=0 if post_match_8_7_10==. & survey=="3-2010"
label var post_match_8_7_10 "Post-semifinal"

gen post_match_29_6_10_kat=post_match_29_6_10*dnac_padres_kat_ambos 
gen post_match_3_7_10_kat=post_match_3_7_10*dnac_padres_kat_ambos 
gen post_match_8_7_10_kat=post_match_8_7_10*dnac_padres_kat_ambos 

label var post_match_29_6_10_kat "Catalan heritage x Post-round of 16"
label var post_match_3_7_10_kat "Catalan heritage x Post-quarterfinal"
label var post_match_8_7_10_kat "Catalan heritage x Post-semifinal"

global controls_nolangnopadremadre female casado educ_* ingr_* empleo_* nac_esp nac_for edad_* mun_*

*Day after match, restrictions
eststo a: areg cat_feeling dayafter_match $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_restr "Yes"
estadd local info_sam "W3-2010"

*Day after match, all sample
eststo b: areg cat_feeling dayafter_match $controls [pw= POND_GEO ], absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_restr "No"
estadd local info_sam "W3-2010"

*Controlling for days after specific matches
eststo c: areg cat_feeling post_match_29_6_10 post_match_3_7_10 post_match_8_7_10 $controls [pw= POND_GEO ], absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_restr "No"
estadd local info_sam "W3-2010"

*By ethnic group
eststo d: areg cat_feeling dnac_padres_kat_ambos post_match_29_6_10 post_match_3_7_10 post_match_8_7_10 post_match_29_6_10_kat post_match_3_7_10_kat post_match_8_7_10_kat $controls_nolangnopadremadre [pw= POND_GEO ] , absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_restr "No"
estadd local info_sam "W3-2010"

*Effect Euro 2008 using different waves
use data/final/data_ceo_2006_2013.dta, clear

svyset ORDRE [pw= POND_GEO ], strata(strata) || ssu

keep if (MES==4 & ANY==2008) | (MES==6 & ANY==2008) | (MES==7 & ANY==2008) | (MES==10 & ANY==2008)

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edad_* mun_*

gen w3_2008=(MES==6 | MES==7)
gen w4_2008=(MES==10)

label var w3_2008 "Survey during Euro 2008"
label var w4_2008 "Survey after Euro 2008 victory"

foreach y in "dayafter_match" "post_match_29_6_10" "post_match_3_7_10" "post_match_8_7_10" "post_match_29_6_10_kat" "post_match_3_7_10_kat" "post_match_8_7_10_kat"{
gen `y'=.
}

label var dayafter_match "Day after WC match"
label var post_match_29_6_10 "Post-round of 16"
label var post_match_3_7_10 "Post-quarterfinal"
label var post_match_8_7_10 "Post-semifinal"
label var dnac_padres_kat_ambos "Catalan heritage"
label var post_match_29_6_10_kat "Catalan heritage x Post-round of 16"
label var post_match_3_7_10_kat "Catalan heritage x Post-quarterfinal"
label var post_match_8_7_10_kat "Catalan heritage x Post-semifinal"

eststo e: areg cat_feeling w3_2008 w4_2008 $controls_nolang [pw= POND_GEO ], absorb(COMARCA) rob
estadd scalar sta = e(r2_a)
estadd local info_restr "No"
estadd local info_sam "W2-W3-W4-2008"

esttab a b c d e using output/tab_rep/table_rob_worldcup_victories.tex, nonumbers nonotes se label ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(dayafter_match post_match_29_6_10 post_match_3_7_10 dnac_padres_kat_ambos post_match_29_6_10 post_match_3_7_10 post_match_8_7_10 post_match_29_6_10_kat post_match_3_7_10_kat post_match_8_7_10_kat w3_2008 w4_2008) ///
mtitles("(1)" "(2)" "(3)" "(4)" "(5)") ///
mgroups("\makecell{Feeling Catalan}", ///
pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
scalars("sta R-squared" "info_sam Sample" "info_restr Restrictions" ) ///
compress replace