clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Within-Catalonia: Institutional polarization. CEO
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

drop if wave!=3

append using data/final/data_ceo_2006_2013.dta

drop if ANY>2012

drop if wave==. & ANY==2010 & (MES==6 | MES==7)

gen wave_code=1 if ANY==2006 & (MES==6 | MES==7)
replace wave_code=2 if ANY==2006 & (MES==9 | MES==10)
replace wave_code=3 if ANY==2006 & MES==11
replace wave_code=4 if ANY==2007 & MES==3
replace wave_code=5 if ANY==2007 & MES==6
replace wave_code=6 if ANY==2007 & MES==9
replace wave_code=7 if ANY==2007 & MES==11
replace wave_code=8 if ANY==2008 & MES==1
replace wave_code=9 if ANY==2008 & MES==4
replace wave_code=10 if ANY==2008 & (MES==6 | MES==7)
replace wave_code=11 if ANY==2008 & MES==10
replace wave_code=12 if ANY==2009 & MES==1
replace wave_code=13 if ANY==2009 & MES==4
replace wave_code=14 if ANY==2009 & (MES==6 | MES==7)
replace wave_code=15 if ANY==2009 & MES==11
replace wave_code=16 if ANY==2010 & MES==1
replace wave_code=17 if ANY==2010 & MES==4
replace wave_code=18 if ANY==2010 & (MES==6 | MES==7)
replace wave_code=19 if ANY==2010 & MES==10
replace wave_code=20 if ANY==2011 & MES==1
replace wave_code=21 if ANY==2011 & MES==6

ta wave_code, gen(wave_code_)

gen wave_code_18_1=(wave_code_18==1 & estatut==0)
gen wave_code_18_2=(wave_code_18==1 & estatut==1)

egen PROVIwave=group(PROVI wave_code)

global controls_nolangnopadremadre female casado educ_* ingr_* empleo_* nac_esp nac_for edad_* mun_*

forvalues i=1/21{
	gen wavesi_padres_`i'=wave_code_`i'*dnac_padres_kat_ambos
}
gen wavesi_padres_18_2=wave_code_18_2*dnac_padres_kat_ambos

gen post_pl=0 if wave_code<18
replace post_pl=1 if wave_code_18_1==1
gen post_plsi_padres=post_pl*dnac_padres_kat_ambos
label var post_pl "Placebo Post"
label var post_plsi_padres "Placebo Post x Catalan heritage"

***Within-survey
mean rel_catesp [pw = POND_GEO] if HOR_INI<19 & time<7
matrix define ress = e(b) 
local mmm = ress[1,1]
local mm_rel = string(round(`mmm',.01) , "%9.2f")
areg rel_catesp dnac_padres_kat_ambos estatut est_si_padres $controls_nolangnopadremadre [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
est sto inst_cat_ceo_1
estadd local surveyfe "No" , replace
estadd local sample "W3-2010" , replace
estadd local model "Within-survey", replace
estadd local mm "`mm_rel'", replace
***Short term effect
mean rel_catesp [pw = POND_GEO] if wave_code<=19
matrix define ress = e(b) 
local mmm = ress[1,1]
local mm_rel = string(round(`mmm',.01) , "%9.2f")
areg rel_catesp dnac_padres_kat_ambos wave_code_1-wave_code_17 wave_code_18_2 wave_code_19 est_si_padres $controls_nolangnopadremadre [pw= POND_GEO ] if wave_code<=19, absorb(COMARCA) cluster(PROVIwave)
est sto inst_cat_ceo_2
estadd local surveyfe "Yes" , replace
estadd local sample "Jun06-Oct10" , replace
estadd local model "D-D", replace
estadd local mm "`mm_rel'", replace
***One year effect
mean rel_catesp [pw = POND_GEO] if wave_code<=21
matrix define ress = e(b) 
local mmm = ress[1,1]
local mm_rel = string(round(`mmm',.01) , "%9.2f")
areg rel_catesp dnac_padres_kat_ambos wave_code_1-wave_code_17 wave_code_18_2 wave_code_19-wave_code_21 est_si_padres $controls_nolangnopadremadre [pw= POND_GEO ] if wave_code<=21, absorb(COMARCA) cluster(PROVIwave)
est sto inst_cat_ceo_3
estadd local surveyfe "Yes" , replace
estadd local sample "Jun 06-Jun 11" , replace
estadd local model "D-D", replace
estadd local mm "`mm_rel'", replace
***Pre-trends
mean rel_catesp [pw = POND_GEO] if wave_code<=18
matrix define ress = e(b) 
local mmm = ress[1,1]
local mm_rel = string(round(`mmm',.01) , "%9.2f")
areg rel_catesp dnac_padres_kat_ambos i.wave_code post_plsi_padres $controls_nolangnopadremadre [pw= POND_GEO ] if wave_code<=18, absorb(COMARCA) cluster(PROVIwave)
est sto inst_cat_ceo_4
estadd local surveyfe "Yes" , replace
estadd local sample "Jun 06-Jun 10" , replace
estadd local model "D-D", replace
estadd local mm "`mm_rel'", replace

esttab inst_cat_ceo_1 inst_cat_ceo_2 inst_cat_ceo_3 inst_cat_ceo_4 using output/tab_rep/table_polariz_inst_cat.tex, ///
eqlabel(none) nonumbers nonotes se label ///
sfmt(%8.2f) ///
keep(dnac_padres_kat_ambos estatut est_si_padres post_plsi_padres) ///
mtitles("(1)" "(2)" "(3)" "(4)") ///
mgroups("\makecell{More autonomy}", ///
pattern(1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
s(N surveyfe sample model mm, label("Observations" "Wave FE" "Sample" "Model" "Average y")) ///
star(* 0.10 ** 0.05 *** 0.01) replace





