clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Short-term voting
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Statistics
*Voting variables
foreach y in "indep" "indep_old"{
	svy: mean part_`y' if HOR_INI<19 & time<7
	estat sd
	local mm_`y'_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
	local ss_`y'_w3 = string(round(r(sd)[1,1],.01) , "%9.2f")
}

///Voting independentist parties
*Vote independentist
eststo a: areg part_indep estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_city "No"
estadd local info_con "Yes"
estadd local info_sam "CEO"
estadd local info_mm "`mm_indep_w3'"
*Vote independentist old
eststo b: areg part_indep_old estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_city "No"
estadd local info_con "Yes"
estadd local info_sam "CEO"
estadd local info_mm "`mm_indep_old_w3'"


*******************************************************************************
***Long-term voting: results
*******************************************************************************
***Prediction W3-2010
do code/analysis/appendix/tab/table_a32_a33_a34_aux_prediction_w3.do

***Value for splitting the sample
sum share_v_erc_99, det
local erc_99_p50=`r(p50)'
local erc_99_p75=`r(p75)'

gen estatut=.
label var estatut "Ruling"

***Statistics
*Share indepentist, all sample
sum share_v_allindep if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015)
local mm_indep_all = string(round(`r(mean)',.01) , "%9.2f")
*Share turnout, all sample
sum turnout if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015)
local mm_turnout_all = string(round(`r(mean)',.01) , "%9.2f")
*Share indepentist, ERC cities
sum share_v_allindep if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015) & share_v_erc_99>`erc_99_p50'
local mm_indep_ercmore = string(round(`r(mean)',.01) , "%9.2f")
*Share indepentist, non-ERC cities
sum share_v_allindep if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015) & share_v_erc_99<=`erc_99_p50'
local mm_indep_ercless = string(round(`r(mean)',.01) , "%9.2f")

*Voting, all cities
eststo c: areg share_v_allindep post2010 post2010me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015), absorb(codiine) rob
estadd scalar sta = e(r2_a)
estadd local info_com "No"
estadd local info_city "Yes"
estadd local info_con "No"
estadd local info_sam "All cities"
estadd local info_mm "`mm_indep_all'"
*Turnout, all cities
eststo d: areg turnout post2010 post2010me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015), absorb(codiine) rob
estadd scalar sta = e(r2_a)
estadd local info_com "No"
estadd local info_city "Yes"
estadd local info_con "No"
estadd local info_sam "All cities"
estadd local info_mm "`mm_turnout_all'"
*Voting, ERC cities
eststo e: areg share_v_allindep post2010 post2010me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015) & share_v_erc_99>`erc_99_p50', absorb(codiine) rob
estadd scalar sta = e(r2_a)
estadd local info_com "No"
estadd local info_city "Yes"
estadd local info_con "No"
estadd local info_sam "ERC-99 P50+"
estadd local info_mm "`mm_indep_ercmore'" 
*Voting, non-ERC cities
eststo f: areg share_v_allindep post2010 post2010me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015) & share_v_erc_99<=`erc_99_p50', absorb(codiine) rob
estadd scalar sta = e(r2_a)
estadd local info_com "No"
estadd local info_city "Yes"
estadd local info_con "No"
estadd local info_sam "ERC-99 P50-"
estadd local info_mm "`mm_indep_ercless'" 

esttab a b c d e f using output/tab_rep/table_pers_voting.tex, eqlabel(none) nonumbers nonotes se label ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(estatut post2010 post2010me_est) ///
mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(6)") ///
mgroups("\makecell{Future vote}" "\makecell{Past vote}" "\makecell{Share Indep.}" "\makecell{Turnout}" "\makecell{Share Indep.}", ///
pattern(1 1 1 1 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
scalars("sta R-squared" "info_com Comarca FE" "info_city City FE" "info_con Controls" "info_sam Sample" "info_mm Average y") ///
compress replace
