clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Long-term voting robustness: pre-trends
*******************************************************************************
***Prediction W3-2010
do code/analysis/appendix/tab/table_a32_a33_a34_aux_prediction_w3.do

***Value for splitting the sample
sum share_v_erc_99, det
local erc_99_p50=`r(p50)'
local erc_99_p75=`r(p75)'

*Placebo in 2003
eststo a: areg share_v_allindep post2003 post2003me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015), absorb(codiine) rob
estadd scalar sta = e(r2_a)
estadd local info_city "Yes"
estadd local info_predsam "W3-2010"
estadd local info_years "99-03-06-15"
estadd local info_sam "All cities"
estadd local info_se "Rob"
*Placebo in 2006
eststo b: areg share_v_allindep post2006 post2006me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015), absorb(codiine) rob
estadd local info_city "Yes"
estadd local info_predsam "W3-2010"
estadd local info_years "99-03-06-15"
estadd local info_sam "All cities"
estadd local info_se "Rob"

*******************************************************************************
***Long-term voting: robustness W2-W3-2010
*******************************************************************************
***Prediction W2-W3-2010
do code/analysis/appendix/tab/table_a34_aux_prediction_w2_w3.do

***Value for splitting the sample
sum share_v_erc_99, det
local erc_99_p50=`r(p50)'
local erc_99_p75=`r(p75)'

*Voting, ERC cities
eststo c: areg share_v_allindep post2010 post2010me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015) & share_v_erc_99>`erc_99_p50', absorb(codiine) rob
estadd local info_city "Yes"
estadd local info_predsam "W2-W3-2010"
estadd local info_years "99-03-06-15"
estadd local info_sam "ERC-99 P50+"
estadd local info_se "Rob"
*Voting, non-ERC cities
eststo d: areg share_v_allindep post2010 post2010me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015) & share_v_erc_99<=`erc_99_p50', absorb(codiine) rob
estadd local info_city "Yes"
estadd local info_predsam "W2-W3-2010"
estadd local info_years "99-03-06-15"
estadd local info_sam "ERC-99 P50-"
estadd local info_se "Rob"

*******************************************************************************
***Long-term voting: robustness bootstrap
*******************************************************************************
***Voting database: additional cleaning
do code/analysis/appendix/tab/table_a34_aux_cleaning_voting.do

***Prediction database
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

*Generate interactions between province and dummy for size cities
egen provimun=group(PROVI HABITAT)
tab provimun if PROVI==1 & HABITAT==6
replace provimun=0 if provimun==6
replace provimun=provimun-1 if provimun>6
tabulate provimun, gen(provimun_d)
foreach var of varlist provimun_d*{
gen est_`var'=estatut*`var'
}
drop est_provimun_d1 provimun_d1

*Estimate independence equation with province-size heterogeneities
label var est_provimun_d2 "Ruling x BCN less 2k inh."
label var est_provimun_d3 "Ruling x BCN 2k-10k inh."
label var est_provimun_d4 "Ruling x BCN 10k-50k inh."
label var est_provimun_d5 "Ruling x BCN 50-150k inh."
label var est_provimun_d6 "Ruling x BCN 150k-1mil inh."
label var est_provimun_d7 "Ruling x GIR less 2k inh."
label var est_provimun_d8 "Ruling x GIR 2k-10k inh."
label var est_provimun_d9 "Ruling x GIR 10k-50k inh."
label var est_provimun_d10 "Ruling x GIR 50k-150k inh."
label var est_provimun_d11 "Ruling x LLE less 2k inh."
label var est_provimun_d12 "Ruling x LLE 2k-10k inh."
label var est_provimun_d13 "Ruling x LLE 10k-50k inh."
label var est_provimun_d14 "Ruling x LLE 50k-150k inh."
label var est_provimun_d15 "Ruling x TAR less 2k inh."
label var est_provimun_d16 "Ruling x TAR 2k-10k inh."
label var est_provimun_d17 "Ruling x TAR 10k-50k inh."
label var est_provimun_d18 "Ruling x TAR 50k-150k inh."

keep indep estatut est_provimun_d* provimun_d* $controls POND_GEO HOR_INI time PROVItime PROVI HABITAT provimun

gen post2010me_est=.
gen post2003=.
gen post2003me_est=.
gen post2006=.
gen post2006me_est=.

label var post2010 "Post 2010"
label var post2010me_est "Post 2010 X M.E. Ruling"
label var post2003 "Post 2003"
label var post2003me_est "Post 2003 X M.E. Ruling"
label var post2006 "Post 2006"
label var post2006me_est "Post 2006 X M.E. Ruling"

***Bootstrap command
do code/analysis/appendix/tab/table_a34_aux_bootstrap.do

***Bootstrap estimates
*ERC cities
eststo e: bootstrap  post2010=r(ate_1) post2010me_est=r(ate_2) ///
		,rep(500) seed(123) nowarn: 	///
		myboot_more

estadd local info_city "Yes"
estadd local info_predsam "W3-2010"
estadd local info_years "99-03-06-15"
estadd local info_sam "ERC-99 P50+"
estadd local info_se "Boot"

*Non-ERC cities
eststo f: bootstrap  post2010=r(ate_1) post2010me_est=r(ate_2) ///
		,rep(500) seed(123) nowarn: 	///
		myboot_less

estadd local info_city "Yes"
estadd local info_predsam "W3-2010"
estadd local info_years "99-03-06-15"
estadd local info_sam "ERC-99 P50-"
estadd local info_se "Boot"

*******************************************************************************
***Long-term voting: robustness
*******************************************************************************
***Prediction W2-W3-2010
do code/analysis/appendix/tab/table_a34_aux_prediction_w2_w3.do

***Value for splitting the sample
sum share_v_erc_99, det
local erc_99_p50=`r(p50)'
local erc_99_p75=`r(p75)'

*ERC-cities
eststo g: areg share_v_ercciujunts post2010 post2010me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015) & share_v_erc_99>`erc_99_p50', absorb(codiine) rob
estadd local info_city "Yes"
estadd local info_predsam "W3-2010"
estadd local info_years "99-03-06-15"
estadd local info_sam "ERC-99 P50+"
estadd local info_se "Rob"

*Non-ERC cities
eststo h: areg share_v_ercciujunts post2010 post2010me_est if (iloc==8 | junts==1) & (t_loc==1999 | t_loc==2003 | t_loc==2006 | t_loc==2015) & share_v_erc_99<=`erc_99_p50', absorb(codiine) rob
estadd local info_city "Yes"
estadd local info_predsam "W3-2010"
estadd local info_years "99-03-06-15"
estadd local info_sam "ERC-99 P50-"
estadd local info_se "Rob"

*******************************************************************************
***Create table
*******************************************************************************
esttab a b c d e f g h using output/tab_rep/table_pers_voting_rob.tex, eqlabel(none) nonumbers nonotes se label ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(post2003 post2003me_est post2006 post2006me_est post2010 post2010me_est) ///
mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)") ///
mgroups("\makecell{Share Indep.}" "\makecell{Share ERC+CiU}", ///
pattern(1 0 0 0 0 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
scalars("sta R-squared" "info_city City FE" "info_predsam Pred. sample" "info_years Vot. years" "info_sam Vot. sample" "info_se s.e.") ///
compress replace