clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Main results, effect of controls: Table
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

global controls_age female casado educ_* ingr_* empleo_* *_cat nac_* edad_* mun_*

***Statistics and standardized variables
*More autonomy, W3-2010
svy: mean rel_catesp if HOR_INI<19 & time<7
estat sd
local mm_rel_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
local ss_rel_w3 = string(round(r(sd)[1,1],.01) , "%9.2f")
*Independence, W3-2010
svy: mean indep if HOR_INI<19 & time<7
estat sd
local mm_indep_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
local ss_indep_w3 = string(round(r(sd)[1,1],.01) , "%9.2f")


///Main result
*More autonomy, unconditional
eststo a: reg rel_catesp estatut  [pw= POND_GEO ] if HOR_INI<19 & time<7, cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "No"
estadd local info_whd "No"
estadd local info_sam "W3-2010"
estadd local info_restr "Yes"
estadd local info_est "OLS"
estadd local info_mm "`mm_rel_w3'"

*More autonomy, conditional
eststo b: areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_whd "No"
estadd local info_sam "W3-2010"
estadd local info_restr "Yes"
estadd local info_est "OLS"
estadd local info_mm "`mm_rel_w3'"

*Indipendence, conditional
svy: mean indep if HOR_INI<19 & time<7
matrix define ress = e(b)
local mmm = ress[1,1]
local mm = string(round(`mmm',.01) , "%9.2f")
eststo c: areg indep estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_whd "No"
estadd local info_sam "W3-2010"
estadd local info_restr "Yes"
estadd local info_est "OLS"
estadd local info_mm "`mm_indep_w3'"

*More autonomy, ordered probit
eststo d: oprobit rel_catesp estatut $controls i.COMARCA [pw= POND_GEO ] if HOR_INI<19 & time<7,  cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_whd "No"
estadd local info_sam "W3-2010"
estadd local info_restr "Yes"
estadd local info_est "O-Probit"
estadd local info_mm "`mm_rel_w3'"

///Using additional waves
use data/final/data_ceo_restr.dta, clear

keep if survey=="2-2010" | survey=="3-2010" | survey=="4-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

gen sample=1 if survey=="2-2010" & HOR_INI<19
replace sample=1 if survey=="3-2010" & HOR_INI<19 & time<7
replace sample=1 if survey=="4-2010" & HOR_INI<19

***Statistics and standardized variables
*More autonomy, W3-2010
svy: mean rel_catesp if HOR_INI<19 & time<7 & survey=="3-2010"
estat sd
local mm_rel_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
local ss_rel_w3 = string(round(r(sd)[1,1],.01) , "%9.2f")
*More autonomy, W2-W3-2010
svy: mean rel_catesp if survey!="4-2010"
estat sd
local mm_rel_w2w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
local ss_rel_w2w3 = string(round(r(sd)[1,1],.01) , "%9.2f")
*More autonomy, W2-W3-W4-2010
svy: mean rel_catesp 
estat sd
local mm_rel_w2w3w4 = string(round(r(mean)[1,1],.01) , "%9.2f")
local ss_rel_w2w3w4= string(round(r(sd)[1,1],.01) , "%9.2f")

***Third wave as control
eststo e: areg rel_catesp estatut $controls i.wave 1.d_HOR_INI_19 1.d_time_7 [pw= POND_GEO ] if survey!="4-2010", absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_whd "Yes"
estadd local info_sam "W2-W3-2010"
estadd local info_restr "No"
estadd local info_est "OLS"
estadd local info_mm "`mm_rel_w2w3'"

***Second wave as control and fourth as treatment
eststo f: areg rel_catesp estatut $controls i.wave 1.d_HOR_INI_19 1.d_time_7 [pw= POND_GEO ] , absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_whd "Yes"
estadd local info_sam "W2-W3-W4-2010"
estadd local info_restr "Yes"
estadd local info_est "OLS"
estadd local info_mm "`mm_rel_w3'"

***Second wave as control and fourth as treatment
eststo f: areg rel_catesp estatut $controls i.wave 1.d_HOR_INI_19 1.d_time_7 [pw= POND_GEO ] , absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_whd "Yes"
estadd local info_sam "W2-W3-W4-2010"
estadd local info_restr "No"
estadd local info_est "OLS"
estadd local info_mm "`mm_rel_w2w3w4'"

***Third wave and categorical age
eststo g: areg rel_catesp estatut $controls_age [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_whd "No"
estadd local info_sam "W3-2010"
estadd local info_restr "No"
estadd local info_est "OLS"
estadd local info_mm "`mm_rel_w2w3w4'"

esttab a b c d e f g using output/tab_rep/table_main_controls.tex, eqlabel(none) nonumbers nonotes se label nomtitles ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(estatut female casado educ_menoseso educ_eso educ_bach ingr_1000 ingr_1001_2000 ingr_2001_3000 empleo_aut empleo_dep casa_cat trabajo_cat amigos_cat entr_cat nac_esp nac_for nac_padre_esp nac_padre_for nac_madre_esp nac_madre_for edat edat2 edad_1834 edad_3549 edad_5064 mun_0_2000 mun_2001_10000 mun_10001_50000 mun_50001_150000 mun_150001_1000000) ///
prehead(\begin{tabular}{lccccccc} \hline \hline & \multicolumn{2}{c}{More autonomy} & Independence & \multicolumn{4}{c}{More autonomy} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-4} \cmidrule(lr){5-8} & (1) & (2) & (3) & (4) & (5) & (6) & (7) \\ \hline) /// 
scalars("sta R-squared" "info_com Comarca FE" ///
"info_whd Wave, Post-h19, Post-Day7 FEs" "info_sam Sample" ///
"info_restr Restrictions" "info_est Estimation" "info_mm Average y") ///
postfoot(\hline \hline \\ \end{tabular}) ///
compress replace