clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Balancing and importance catalan heritage
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

***Statistics and standardized variables
*Catalan heritage
svy: mean dnac_padres_kat_ambos if HOR_INI<19 & time<7
estat sd
local mm_cather_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
*Feeling catalan
svy: mean cat_feeling if HOR_INI<19 & time<7
estat sd
local mm_feel_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
*More autonomy
svy: mean rel_catesp if HOR_INI<19 & time<7
estat sd
local mm_rel_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")

***Balancing
eststo a: reg dnac_padres_kat_ambos estatut [pw= POND_GEO ] if HOR_INI<19 & time<7, cluster(PROVItime)
estadd scalar sta = abs(e(r2_a))
estadd local info_com "No"
estadd local info_con "No"
estadd local info_mm "`mm_cather_w3'"
***Identity (not both parents)
gen nac_kat2=nac_kat
gen nac_for2=nac_for
eststo b: areg cat_feeling nac_kat2 nac_for2 female casado educ_menoseso educ_eso educ_bach ingr_1000 ingr_1001_2000 ingr_2001_3000 empleo_aut empleo_dep edad_1834 edad_3549 edad_5064 mun_0_2000 mun_2001_10000 mun_10001_50000 mun_50001_150000 mun_150001_1000000 [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_con "Yes"
estadd local info_mm "`mm_feel_w3'"
***Identity (both parents)
eststo c: areg cat_feeling dnac_padres_kat_ambos nac_kat nac_for female casado educ_* ingr_* empleo_* edad_* mun_* [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_con "Yes"
estadd local info_mm "`mm_feel_w3'"
***More autonomy
eststo d: areg rel_catesp dnac_padres_kat_ambos nac_kat nac_for female casado educ_* ingr_* empleo_* edad_* mun_* [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_com "Yes"
estadd local info_con "Yes"
estadd local info_mm "`mm_rel_w3'"

esttab a b c d using output/tab_rep/table_bal_cat.tex, eqlabel(none) nonumbers nonotes se label ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(estatut dnac_padres_kat_ambos nac_kat) ///
mtitles("(1)" "(2)" "(3)" "(4)") ///
mgroups("\makecell{Catalan heritage}" "\makecell{Feeling Catalan}" "\makecell{More autonomy}", ///
pattern(1 1 0 1) prefix(\multicolumn{@span}{c}{) suffix(}) ///
span erepeat(\cmidrule(lr){@span})) ///
scalars("sta R-squared" "info_com Comarca FE" "info_con Controls" "info_mm Average y") ///
compress replace


