clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Pre-trends between waves
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

append using data/final/data_ceo_2006_2013.dta

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edad_* mun_*

*Drop observations after 2012
drop if ANY>2012

*Drop observations from wave 3 of 2010 from 2006-2013 unrestricted data
drop if wave==. & ANY==2010 & (MES==6 | MES==7)

*Generate wave codes
gen wave_code=1 if ANY==2006 & (MES==6 | MES==7)
replace wave_code=2 if ANY==2006 & (MES==9 | MES==10)
replace wave_code=3 if ANY==2006 & MES==11
replace wave_code=4 if ANY==2007 & MES==3
replace wave_code=5 if ANY==2007 & MES==6
replace wave_code=6 if ANY==2007 & MES==9
replace wave_code=7 if ANY==2007 & MES==11
replace wave_code=8 if ANY==2008 & MES==1
replace wave_code=9 if ANY==2008 & MES==4
replace wave_code=10 if ANY==2008 & (MES==6 | MES==7)
replace wave_code=11 if ANY==2008 & MES==10
replace wave_code=12 if ANY==2009 & MES==1
replace wave_code=13 if ANY==2009 & MES==4
replace wave_code=14 if ANY==2009 & (MES==6 | MES==7)
replace wave_code=15 if ANY==2009 & MES==11
replace wave_code=16 if ANY==2010 & MES==1
replace wave_code=17 if ANY==2010 & MES==4
replace wave_code=18 if ANY==2010 & (MES==6 | MES==7)
replace wave_code=19 if ANY==2010 & MES==10
replace wave_code=20 if ANY==2011 & MES==1
replace wave_code=21 if ANY==2011 & MES==6

ta wave_code, gen(wave_code_)

gen wave_code_18_1=(wave_code_18==1 & estatut==0)
gen wave_code_18_2=(wave_code_18==1 & estatut==1)

*Generate clustering variable
egen PROVIwave=group(PROVI wave_code)

***Regression
reg rel_catesp wave_code_1-wave_code_17 wave_code_18_2 wave_code_19-wave_code_21 [pw= POND_GEO ] if wave_code<=21, cluster(PROVIwave)

mat treat = J(22,4,1)

mat treat[18,1] = 18
mat treat[18,2] = 0
mat treat[18,3] = 0
mat treat[18,4] = 0

forval yy = 1(1)17 {
local pos=`yy'
mat treat[`pos',1] = `pos'
mat treat[`pos',2] = _b[wave_code_`yy']
mat treat[`pos',3] = _b[wave_code_`yy'] + _se[wave_code_`yy']*invttail(e(N),0.025)
mat treat[`pos',4] = _b[wave_code_`yy'] - _se[wave_code_`yy']*invttail(e(N),0.025)
}

mat treat[19,1] = 19
mat treat[19,2] = _b[wave_code_18_2]
mat treat[19,3] = _b[wave_code_18_2] + _se[wave_code_18_2]*invttail(e(N),0.025)
mat treat[19,4] = _b[wave_code_18_2] - _se[wave_code_18_2]*invttail(e(N),0.025)

forval yy = 19(1)21 {
local pos=`yy'+1
mat treat[`pos',1] = `pos'
mat treat[`pos',2] = _b[wave_code_`yy']
mat treat[`pos',3] = _b[wave_code_`yy'] + _se[wave_code_`yy']*invttail(e(N),0.025)
mat treat[`pos',4] = _b[wave_code_`yy'] - _se[wave_code_`yy']*invttail(e(N),0.025)
}

g yy = treat[_n,1] in 1/22
g eff = treat[_n,2] in 1/22
g eff_5 = treat[_n,3] in 1/22
g eff_95 = treat[_n,4] in 1/22

label var eff "Coefficient"
label var eff_5 "Lower bound CI 5"
label var eff_95 "Higher bound CI 95"

sort wave_code

twoway (rcap eff_5 eff_95 yy, lc(gs10) yaxis(1) )  (scatter eff yy, mc(gs3) xtitle("Survey wave")  title("Change in support for more autonomy") xlabel(2 "Sep/Oct-06" 6 "Sep-07" 10 "Jun/Jul-08" 14 "Jun/Jul-09" 18 "Jun-10-C" 19 "Jun/Jul-10-T" 22 "Jun-11", angle(45)) legend(position(6) rows(1)) ), yline(0,lc(black) lp(-)) xline(18.2, lcolor(red)) text(0.3 18.3 "Ruling", color(red) placement(e) orient(hor))
graph export output/fig_rep/figure_pretrends_06_11.png, as(png) replace


