clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Robustness combined with multiple hypothesis testing
*******************************************************************************

*******************************************************************************
***Generating waiting time of the interview and additional variables
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="2-2010" | survey=="3-2010"

***Waiting time of interviews
do code/analysis/paper/fig/figure_3_aux_cleaning_wait.do

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

*******************************************************************************
***Unadjusted p-values
*******************************************************************************
mat def pvalue = J(11, 1, .)

***Baseline
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[1,1]=r(p)

***No controls
reg rel_catesp estatut [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", cluster(PROVItime)
test estatut=0
mat pvalue[2,1]=r(p)

***No comarca FE
reg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", cluster(PROVItime)
test estatut=0
mat pvalue[3,1]=r(p)

***Province FE
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", absorb(PROVI) cluster(PROVItime)
test estatut=0
mat pvalue[4,1]=r(p)

***Province x city size FE
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", absorb(group_ps) cluster(PROVItime)
test estatut=0
mat pvalue[5,1]=r(p)

***No day restriction
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[6,1]=r(p)

***No hour restriction
areg rel_catesp estatut $controls [pw= POND_GEO ] if time<7 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[7,1]=r(p)

***No day and hour restriction
areg rel_catesp estatut $controls [pw= POND_GEO ] if survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[8,1]=r(p)

***Balanced sample
*Define sample
areg rel_catesp estatut $controls [pw= POND_GEO ] if  HOR_INI<19 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
gen SAMPLE=e(sample)
sort time HOR_INI MIN_INI
egen seq=seq() if survey=="3-2010" & SAMPLE==1
*Regression
areg rel_catesp estatut $controls [pw= POND_GEO ] if seq<=340 & SAMPLE==1 & HOR_INI<19 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[9,1]=r(p)

***W2 as control
areg rel_catesp estatut $controls i.wave [pw= POND_GEO ] if HOR_INI<19, absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[10,1]=r(p)

***Controlling for waiting time
areg rel_catesp estatut $controls wait_my [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)
test estatut=0
mat pvalue[11,1]=r(p)


*******************************************************************************
***P-value correction for multiple hypothesis testing
*******************************************************************************
preserve
svmat pvalue 
gen outcome = _n

rename pvalue1 pval

include "code/analysis/paper/fig/figure_3_aux_fdr_sharpened_qvalues.do"


keep bky06_qval
mkmat bky06_qval, mat(fdrpvals)
restore 

*******************************************************************************
***Compute 95% CI from adjusted p-values
*******************************************************************************
***Create matrix to store results
matrix estimates = J(11, 4, .)

***Baseline
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_1 = 1
scalar pvalue_adj_1 = fdrpvals[1,1]
scalar beta_1 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_1 = invttail(e(df_r), pvalue_adj_1 / 2)
*Calculating standard error
scalar se_1 = beta_1/abs(t_val_1) 
*Calculating interval
scalar u95_1 = beta_1+invt(e(df_r),0.975) * se_1 
scalar l95_1 = beta_1-invt(e(df_r),0.975) * se_1  
*Matrix list estimates
matrix estimates[1, 1] = spec_id_1
matrix estimates[1, 2] = beta_1
matrix estimates[1, 3] = l95_1
matrix estimates[1, 4] = u95_1

***No controls
reg rel_catesp estatut  [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_2 = 2
scalar pvalue_adj_2 = fdrpvals[2,1]
scalar beta_2 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_2 = invttail(e(df_r), pvalue_adj_2 / 2)
*Calculating standard error
scalar se_2 = beta_2/abs(t_val_2) 
*Calculating interval
scalar u95_2 = beta_2+invt(e(df_r),0.975) * se_2 
scalar l95_2 = beta_2-invt(e(df_r),0.975) * se_2  
*Matrix list estimates
matrix estimates[2, 1] = spec_id_2
matrix estimates[2, 2] = beta_2
matrix estimates[2, 3] = l95_2
matrix estimates[2, 4] = u95_2

***No comarca FE
reg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_3 = 3
scalar pvalue_adj_3 = fdrpvals[3,1]
scalar beta_3 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_3 = invttail(e(df_r), pvalue_adj_3 / 2)
*Calculating standard error
scalar se_3 = beta_3/abs(t_val_3) 
*Calculating interval
scalar u95_3 = beta_3+invt(e(df_r),0.975) * se_3 
scalar l95_3 = beta_3-invt(e(df_r),0.975) * se_3  
*Matrix list estimates
matrix estimates[3, 1] = spec_id_3
matrix estimates[3, 2] = beta_3
matrix estimates[3, 3] = l95_3
matrix estimates[3, 4] = u95_3

***Province FE
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", absorb(PROVI) cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_4 = 4
scalar pvalue_adj_4 = fdrpvals[4,1]
scalar beta_4 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_4 = invttail(e(df_r), pvalue_adj_4 / 2)
*Calculating standard error
scalar se_4 = beta_4/abs(t_val_4) 
*Calculating interval
scalar u95_4 = beta_4+invt(e(df_r),0.975) * se_4
scalar l95_4 = beta_4-invt(e(df_r),0.975) * se_4  
*Matrix list estimates
matrix estimates[4, 1] = spec_id_4
matrix estimates[4, 2] = beta_4
matrix estimates[4, 3] = l95_4
matrix estimates[4, 4] = u95_4

***Province x city size FE
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", absorb(group_ps) cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_5 = 5
scalar pvalue_adj_5 = fdrpvals[5,1]
scalar beta_5 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_5 = invttail(e(df_r), pvalue_adj_5 / 2)
*Calculating standard error
scalar se_5 = beta_5/abs(t_val_5) 
*Calculating interval
scalar u95_5 = beta_5+invt(e(df_r),0.975) * se_5
scalar l95_5 = beta_5-invt(e(df_r),0.975) * se_5  
*Mmatrix list estimates
matrix estimates[5, 1] = spec_id_5
matrix estimates[5, 2] = beta_5
matrix estimates[5, 3] = l95_5
matrix estimates[5, 4] = u95_5

***No day restrictions
areg rel_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_6 = 6
scalar pvalue_adj_6 = fdrpvals[6,1]
scalar beta_6 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_6 = invttail(e(df_r), pvalue_adj_6 / 2)
*Calculating standard error
scalar se_6 = beta_6/abs(t_val_6) 
*Calculating interval
scalar u95_6 = beta_6+invt(e(df_r),0.975) * se_6 
scalar l95_6 = beta_6-invt(e(df_r),0.975) * se_6  
*Matrix list estimates
matrix estimates[6, 1] = spec_id_6
matrix estimates[6, 2] = beta_6
matrix estimates[6, 3] = l95_6
matrix estimates[6, 4] = u95_6

***No hour restrictions
areg rel_catesp estatut $controls [pw= POND_GEO ] if time<7 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_7 = 7
scalar pvalue_adj_7 = fdrpvals[7,1]
scalar beta_7 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_7 = invttail(e(df_r), pvalue_adj_7 / 2)
*Calculating standard error
scalar se_7 = beta_7/abs(t_val_7) 
*Calculating interval
scalar u95_7 = beta_7+invt(e(df_r),0.975) * se_7 
scalar l95_7 = beta_7-invt(e(df_r),0.975) * se_7 
*Matrix list estimates
matrix estimates[7, 1] = spec_id_7
matrix estimates[7, 2] = beta_7
matrix estimates[7, 3] = l95_7
matrix estimates[7, 4] = u95_7

***No day and hour restrictions
areg rel_catesp estatut $controls [pw= POND_GEO ] if survey=="3-2010", absorb(COMARCA) cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_8 = 8
scalar pvalue_adj_8 = fdrpvals[8,1]
scalar beta_8 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_8 = invttail(e(df_r), pvalue_adj_8 / 2)
*Calculating standard error
scalar se_8 = beta_8/abs(t_val_8) 
*Calculating interval
scalar u95_8 = beta_8+invt(e(df_r),0.975) * se_8 
scalar l95_8 = beta_8-invt(e(df_r),0.975) * se_8  
*Matrix list estimates
matrix estimates[8, 1] = spec_id_8
matrix estimates[8, 2] = beta_8
matrix estimates[8, 3] = l95_8
matrix estimates[8, 4] = u95_8

***Balanced sample
areg rel_catesp estatut $controls [pw= POND_GEO ] if seq<=340 & SAMPLE==1 & HOR_INI<19 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_9 = 9
scalar pvalue_adj_9 = fdrpvals[9,1]
scalar beta_9 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_9 = invttail(e(df_r), pvalue_adj_9 / 2)
*Calculating standard error
scalar se_9 = beta_9/abs(t_val_9) 
*Calculating interval
scalar u95_9 = beta_9+invt(e(df_r),0.975) * se_9 
scalar l95_9 = beta_9-invt(e(df_r),0.975) * se_9  
*Matrix list estimates
matrix estimates[9, 1] = spec_id_9
matrix estimates[9, 2] = beta_9
matrix estimates[9, 3] = l95_9
matrix estimates[9, 4] = u95_9

***W2 as control
areg rel_catesp estatut $controls i.wave [pw= POND_GEO ] if HOR_INI<19, absorb(COMARCA) cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_10 = 10
scalar pvalue_adj_10 = fdrpvals[10,1]
scalar beta_10 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_10 = invttail(e(df_r), pvalue_adj_10 / 2)
*Calculating standard error
scalar se_10 = beta_10/abs(t_val_10) 
*Calculating interval
scalar u95_10 = beta_10+invt(e(df_r),0.9105) * se_10 
scalar l95_10 = beta_10-invt(e(df_r),0.9105) * se_10  
*Matrix list estimates
matrix estimates[10, 1] = spec_id_10
matrix estimates[10, 2] = beta_10
matrix estimates[10, 3] = l95_10
matrix estimates[10, 4] = u95_10

***Controlling for waiting time
areg rel_catesp estatut $controls wait_my [pw= POND_GEO ] if HOR_INI<19 & time<7 & survey=="3-2010", absorb(COMARCA) cluster(PROVItime)

*Set specification number, adjusted p-value and beta
scalar spec_id_11 = 11
scalar pvalue_adj_11 = fdrpvals[11,1]
scalar beta_11 =  _b[estatut]
*Calculating the t-value using quantile function
scalar t_val_11 = invttail(e(df_r), pvalue_adj_11 / 2)
*Calculating standard error
scalar se_11 = beta_11/abs(t_val_11) 
*Calculating interval
scalar u95_11 = beta_11+invt(e(df_r),0.115) * se_11 
scalar l95_11 = beta_11-invt(e(df_r),0.115) * se_11
*Matrix list estimates
matrix estimates[11, 1] = spec_id_11
matrix estimates[11, 2] = beta_11
matrix estimates[11, 3] = l95_11
matrix estimates[11, 4] = u95_11


*******************************************************************************
***Create graph
*******************************************************************************
***Variables for labels of the graph
matrix list estimates

svmat double estimates

keep estimates1 estimates2 estimates3 estimates4

rename estimates1 spec_id
rename estimates2 beta
rename estimates3 l95
rename estimates4 u95
keep in 1/11

gen main = . 
replace main = 1 if spec_id == 1

gen controls = . 
replace controls = 1 if spec_id == 1 | spec_id == 3 | spec_id == 4 | spec_id == 5 | spec_id == 6 | spec_id == 7 | spec_id == 8 | spec_id == 9 | spec_id == 10 | spec_id == 11

gen comarca_fe = . 
replace comarca_fe = 1 if spec_id == 1 | spec_id == 6 | spec_id == 7 | spec_id == 8 | spec_id == 9 | spec_id == 10 | spec_id == 11

gen hour_res = . 
replace hour_res = 1 if spec_id == 1 | spec_id == 2 | spec_id == 3 | spec_id == 4 | spec_id == 5 | spec_id == 6 | spec_id == 9 | spec_id == 10 | spec_id == 11

gen day_res = . 
replace day_res = 1 if spec_id == 1 | spec_id == 2 | spec_id == 3 | spec_id == 4 | spec_id == 5 | spec_id == 7 | spec_id == 9 | spec_id == 11 

gen prov_fe = . 
replace prov_fe = 1 if spec_id == 4

gen prov_citysize_fe = . 
replace prov_citysize_fe = 1 if spec_id == 5

gen balanced_sample = . 
replace balanced_sample = 1 if spec_id == 9

gen w2_2010 = . 
replace w2_2010 = 1 if spec_id == 10

gen wave_fe = . 
replace wave_fe = 1 if spec_id == 10

gen waiting_time = . 
replace waiting_time = 1 if spec_id == 11

*New variable for number of column
gen id = "(" + string(_n) + ")"

***Create chart
* rank
gen rank=_n
*Generate indicators and scatters
	local scoff=" "
	local scon=" "
	local scot=" "
	local ind=-0.1
	foreach var in controls comarca_fe prov_fe prov_citysize_fe hour_res day_res balanced_sample w2_2010 wave_fe waiting_time {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.03
	   local scoff="`scoff' (scatter i_`var' rank,msize(vsmall) msymbol(d) mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1,msize(small) msymbol(D) mcolor(black))" 
	}
	foreach var in id {
		   cap gen i_`var'=`ind'
		   local ind=`ind'-0.03
		   local scot= "`scot' (scatter i_`var' rank if main==1, mlabel(`var') msize(vtiny) mcolor(white) mlabcolor(black) mlabposition(0))" 
	}

*Plot
tw  (scatter beta rank if main==1, mcolor(black) msymbol(T)  msize(small)) ///  main spec 
   (rbar u95 l95 rank, fcolor(gs11) lcolor(gs16) lwidth(none)) /// 95% CI
   (scatter beta rank if main!=1, mcolor(black) msymbol(O) msize(small)) ///  point estimates
   `scoff' ///
   `scon' /// indicators for spec
  (scatter beta rank if main==1, mcolor(black) msymbol(T)  msize(small)) ///  main spec 
  (scatter i_controls rank if main==1,msymbol(T) msize(vsmall) mcolor(black))  ///
  (scatter i_comarca_fe rank if main==1,msize(vsmall) mcolor(black))  ///
  (scatter i_hour_res rank if main==1,msize(vsmall) mcolor(black))  ///
  (scatter i_day_res rank if main==1,msize(vsmall) mcolor(black))  ///
  `scot' ///
  (scatter i_id rank, mlabel(id) msize(vtiny) mcolor(white) mlabcolor(black) mlabposition(0)) ///
   ,legend (order(1 "Baseline specification" 3 "Point estimate" 2 "95% CI" ) region(lcolor(white)) ///
	pos(12) ring(1) rows(1) size(small) symysize(small) symxsize(small)) ///
   xtitle(" ") ytitle(" ") yline(0, lcolor(black) lstyle(foreground)) ///
   yscale(noline) xscale(noline) ylab(0 "0" 0.1 "0.1" 0.2 "0.2" 0.3 "0.3", nogrid angle(horizontal) labsize(small)) xlab("", noticks)  ///
   graphregion (fcolor(white) lcolor(white)) plotregion(fcolor(white) lcolor(white))
     
*Legend
gr_edit .yaxis1.add_ticks -0.10 `"Controls"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) ) 
gr_edit .yaxis1.add_ticks -0.13 `"Comarca FE"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
gr_edit .yaxis1.add_ticks -0.16 `"Province FE"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
gr_edit .yaxis1.add_ticks -0.19 `"Province x city size FE "', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
gr_edit .yaxis1.add_ticks -0.22 `"Hour restrictions"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
gr_edit .yaxis1.add_ticks -0.25 `"Day restrictions"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
gr_edit .yaxis1.add_ticks -0.28 `"Balanced sample"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
gr_edit .yaxis1.add_ticks -0.31 `"Previous wave in the control"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
gr_edit .yaxis1.add_ticks -0.34 `"Wave FE"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
gr_edit .yaxis1.add_ticks -0.37 `"Control for waiting time"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
*gr_edit .yaxis1.add_ticks -0.40 `"Columns"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
gr_edit .yaxis1.add_ticks 0.35 `"Treatment Effect"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )

graph export           output/fig_rep/rob_combined_multhyptest.png, replace















