clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Problem results: most important
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Statistics
*Problem variables
foreach y in "catesp" "ecolab" "financing"{
	svy: mean problmost_`y' if HOR_INI<19 & time<7
	estat sd
	local mm_`y'_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
	local ss_`y'_w3 = string(round(r(sd)[1,1],.01) , "%9.2f")
}
*Problem specific to estatut
svy: mean problmostspec_estatut if HOR_INI<19 & time<7
estat sd
local mm_estatut_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
local ss_estatut_w3 = string(round(r(sd)[1,1],.01) , "%9.2f")

***Regressions
*Relationship between Catalonia and Spain
eststo a: areg problmost_catesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_catesp_w3'"

*Estatut
eststo b: areg problmostspec_estatut estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_estatut_w3'"

*Economy
eststo c: areg problmost_ecolab estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_ecolab_w3'"

*Financing
eststo d: areg problmost_financing estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_financing_w3'"

esttab a b c d using output/tab_rep/table_probl.tex, eqlabel(none) nonumbers nonotes se label nomtitles ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(estatut) ///
prehead(\begin{tabular}{lcccc} \hline \hline & \multicolumn{4}{c}{Most important problems} \\ & Catalonia- & Statute of & Economy \& & Catalan \\ & Spain & autonomy & labour market & financing \\ \cmidrule(lr){2-5} & (1) & (2) & (3) & (4) \\ \hline) /// 
scalars("sta R-squared" "info_mm Average y") ///
postfoot(\hline \hline \\ \end{tabular}) ///
compress replace
