clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Trust results
*******************************************************************************
use data/final/data_ceo_restr.dta, clear

keep if survey=="3-2010"

svyset Ordre_petició [pw= POND_GEO ], strata(strata) || ssu

global controls female casado educ_* ingr_* empleo_* *_cat nac_* edat edat2 mun_*

***Statistics and standardized variables
*Trust variables
foreach y in "trib" "govesp" "parlesp" "govcat" "parlcat" "part"{
	svy: mean trust_`y' if HOR_INI<19 & time<7
	estat sd
	local mm_`y'_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
	local ss_`y'_w3 = string(round(r(sd)[1,1],.01) , "%9.2f")
}
*Insatisfaction democracy
svy: mean satisf_demo_poco if HOR_INI<19 & time<7
estat sd
local mm_demo_w3 = string(round(r(mean)[1,1],.01) , "%9.2f")
local ss_demo_w3 = string(round(r(sd)[1,1],.01) , "%9.2f")

***Regressions
*Courts
eststo a: areg trust_trib estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_trib_w3'"

*Spanish government
eststo b: areg trust_govesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_govesp_w3'"

*Spanish parliament
eststo c: areg trust_parlesp estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_parlesp_w3'"

*Catalan government
eststo d: areg trust_govcat estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_govcat_w3'"

*Catalan parliament
eststo e: areg trust_parlcat estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_parlcat_w3'"

*Parties
eststo f: areg trust_part estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_part_w3'"

*Insatisfaction democracy
eststo g: areg satisf_demo_poco estatut $controls [pw= POND_GEO ] if HOR_INI<19 & time<7, absorb(COMARCA) cluster(PROVItime)
estadd scalar sta = e(r2_a)
estadd local info_mm "`mm_demo_w3'"

esttab a b c d e f g using output/tab_rep/table_trust.tex, eqlabel(none) nonumbers nonotes se label nomtitles ///
sfmt(%8.2f) ///
star(* 0.10 ** 0.05 *** 0.01) keep(estatut) ///
prehead(\begin{tabular}{lccccccc} \hline \hline & \multicolumn{6}{c}{Trust} & Insatisf. \\ & Courts & Esp Gov't & Esp Parl. & Cat Gov't & Cat Parl. & Parties & democr.\\ \cmidrule(lr){2-7} \cmidrule(lr){8-8} & (1) & (2) & (3) & (4) & (5) & (6) & (7) \\ \hline) /// 
scalars("sta R-squared" "info_mm Average y") ///
postfoot(\hline \hline \\ \end{tabular}) ///
compress replace
