clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

/////////////////////////////////////////////////////////////////////////////
///Transform files from sav
/////////////////////////////////////////////////////////////////////////////
***2010 - wave 2 (barometro 581)
import spss using "data/raw/Microdades anonimitzades 581.sav", clear

*Rename to be identical with other databases
rename *, upper
rename ORDRE_PETICIO Ordre_petició
rename CODI_ENQ codi_enq
rename SEXE sexe
rename EDAT edat
rename GR_EDAT gr_edat
rename P1_200_R p1_200_R
rename P1_600_R p1_600_R
rename P1_700_R p1_700_R
rename P1_1200_R p1_1200_R
rename P1_1600_R p1_1600_R
rename P1_9600_R p1_9600_R
rename P1_9500_R p1_9500_R
rename P1_9800_R p1_9800_R
rename P1_9900_R p1_9900_R

*Generate non-proprietary format
export delimited using "data/intermediate/Microdades anonimitzades 581.csv", replace
	 
tempfile database_wave2_2010_restr
save `database_wave2_2010_restr'

***2010 - wave 3 (barometro 600)
import spss using "data/raw/Microdades anonimitzades 600.sav", clear

*Rename to be identical with other databases
rename *, upper
rename ORDRE_PETICIO Ordre_petició
rename CODI_ENQ codi_enq
rename SEXE sexe
rename EDAT edat
rename GR_EDAT gr_edat
rename P1_200_R p1_200_R
rename P1_600_R p1_600_R
rename P1_700_R p1_700_R
rename P1_1200_R p1_1200_R
rename P1_1600_R p1_1600_R
rename P1_9600_R p1_9600_R
rename P1_9500_R p1_9500_R
rename P1_9800_R p1_9800_R
rename P1_9900_R p1_9900_R

*Generate non-proprietary format
export delimited using "data/intermediate/Microdades anonimitzades 600.csv", replace
	 
tempfile database_wave3_2010_restr
save `database_wave3_2010_restr'

***2010 - wave 4 (barometro 612)
import spss using "data/raw/Microdades anonimitzades 612.sav", clear

*Rename to be identical with other databases
rename *, upper
rename ORDRE_PETICIO Ordre_petició
rename CODI_ENQ codi_enq
rename SEXE sexe
rename EDAT edat
rename GR_EDAT gr_edat
rename P1_200_R p1_200_R
rename P1_600_R p1_600_R
rename P1_700_R p1_700_R
rename P1_1200_R p1_1200_R
rename P1_1600_R p1_1600_R
rename P1_9600_R p1_9600_R
rename P1_9500_R p1_9500_R
rename P1_9800_R p1_9800_R
rename P1_9900_R p1_9900_R

*Generate non-proprietary format
export delimited using "data/intermediate/Microdades anonimitzades 612.csv", replace
	 
tempfile database_wave4_2010_restr
save `database_wave4_2010_restr'

///Append

use `database_wave2_2010_restr', clear

gen wave=2
gen survey="2-2010"

append using `database_wave3_2010_restr'

replace wave=3 if wave==.
replace survey="3-2010" if survey==""

append using `database_wave4_2010_restr'

replace wave=4 if wave==.
replace survey="4-2010" if survey==""

/////////////////////////////////////////////////////////////////////////////
///Generate variables
/////////////////////////////////////////////////////////////////////////////

***Preference for Catalan organization
gen rel_catesp=P28
replace rel_catesp=. if P28>=98

gen indep=(P28==4)
replace indep=. if P28>=98

gen regio=(P28==1)
replace regio=. if P28>=98

gen ccaa=(P28==2)
replace ccaa=. if P28>=98

gen estadofed=(P28==3)
replace estadofed=. if P28>=98

gen estatut=0 if HOR_INI<19 & DIA==28 & survey=="3-2010"
replace estatut=1 if (estatut==. & survey=="3-2010")
replace estatut=0 if survey=="3-2009" | survey=="2-2010"
replace estatut=1 if survey=="4-2010" | survey=="2-2011" | survey=="3-2011"


***Time treatment
gen time=0 if DIA==28 & survey=="3-2010"
replace time=1 if DIA==29 & survey=="3-2010"
replace time=2 if DIA==30 & survey=="3-2010"
replace time=DIA+2 if DIA<=8 & survey=="3-2010"
replace time=time-1 if time>6 & survey=="3-2010"

egen time_2=group(DIA) if survey=="2-2010"
replace time=time_2-1 if survey=="2-2010"
drop time_2
egen time_4=group(DIA) if survey=="4-2010"
replace time=time_4-1 if survey=="4-2010"
drop time_4

gen HOR_INI_19=(HOR_INI>19)

gen d_HOR_INI_19=(HOR_INI>=19)
gen d_time_7=(time>=7)

***Cluster
egen PROVItime=group(PROVI time)

***Identity
gen cat_feeling=P25
replace cat_feeling=. if P25>=98
tabulate cat_feeling, gen(ca_feel)

gen nac_esp=(C100==2)
gen nac_for=(C100==3 | C100==4)
gen nac_kat=(C100==1)

gen nac_padre_esp=(C110==2)
gen nac_padre_for=(C110==3 | C110==4)
gen nac_padre_kat=(C110==1)

gen nac_madre_esp=(C120==2)
gen nac_madre_for=(C120==3 | C120==4)
gen nac_madre_kat=(C120==1)

foreach var of varlist nac_padre_*{
replace `var'=. if C110>=98
}

foreach var of varlist nac_madre_*{
replace `var'=. if C120>=98
}

gen casa_cat=(C701==1)
gen trabajo_cat=(C702==1)
gen amigos_cat=(C703==1)
gen entr_cat=(LLENGUA==1)

***Catalan heritage
gen dnac_padres_kat_ambos=(nac_padre_kat==1 & nac_madre_kat==1)
replace dnac_padres_kat_ambos=. if nac_padre_kat==. | nac_madre_kat==.

***Demographics
gen casado=(C600==1)
replace casado=. if C600==99

gen female=(sexe==2)

***Age
gen edad_1834=(gr_edat==1)
gen edad_3549=(gr_edat==2)
gen edad_5064=(gr_edat==3)
gen edad_64=(gr_edat==4)
gen edat2=edat^2

***Education
gen educ_menoseso=(C500<=2)
gen educ_eso=(C500==3)
gen educ_bach=(C500==4)
gen educ_uni=(C500==5 | C500==6)
foreach var of varlist educ_*{
replace `var'=. if C500>=95
}

***Income
gen ingr_1000=(C340==1)
gen ingr_1001_2000=(C340==2)
gen ingr_2001_3000=(C340==3)
gen ingr_3001=(C340==4 | C340==5 | C340==6)
foreach var of varlist ingr_*{
replace `var'=. if C340>=98
}
gen empleo_aut=(C400==1)
gen empleo_dep=(C400==2)
gen empleo_unem=(C400==3)
foreach var of varlist empleo_*{
replace `var'=. if C400==99
}

***TV
gen tv3=(P16A==3)
replace tv3=. if P16A>=98

***Problems
gen probl_precariety=(p1_200_R!=.)
gen probl_catesp=(p1_600_R!=.)
gen probl_financing=(p1_700_R!=.)
gen probl_eco=(p1_1200_R!=.)
gen probl_salarios=(p1_1600_R!=.)
gen probl_ecolab=( probl_precariety==1| probl_eco==1 | probl_salarios==1)
gen problspec_estatut=(P1_601_E!=.)
gen problmost_precariety=(P2_R==200)
gen problmost_catesp=(P2_R==600)
gen problmost_financing=(P2_R==700)
gen problmost_eco=(P2_R==1200)
gen problmost_salarios=(P2_R==1600)
gen problmost_ecolab=( problmost_precariety==1| problmost_eco==1 | problmost_salarios==1)
gen problmostspec_estatut=(P2==601)
foreach var of varlist probl*{
replace `var'=. if p1_9600_R!=. | p1_9500_R!=. | p1_9800_R!=. | p1_9900_R!=. 
}

***Trust
gen trust_trib=P20A
replace trust_trib=. if P20A>=98
gen trust_part=P20B
replace trust_part=. if P20B>=98
gen trust_govesp=P20D
replace trust_govesp=. if P20D>=98
gen trust_govcat=P20F
replace trust_govcat=. if P20F>=98
gen trust_parlesp=P20G
replace trust_parlesp=. if P20G>=98
gen trust_parlcat=P20H
replace trust_parlcat=. if P20H>=98
gen insatisf_demo=P18
replace insatisf_demo=. if P18>=98
gen satisf_demo_poco=(P18==3 | P18==4)
replace satisf_demo_poco=. if P18>=98

***Vote
gen part_indep=(P32==2 | P32==3)
replace part_indep=. if P32>90
gen erc=(P32==3)
replace erc=. if P32>90
gen ciu=(P32==2)
replace ciu=. if P32>90
gen ppc=(P32==1)
replace ppc=. if P32>90
gen psc=(P32==4)
replace psc=. if P32>90
gen icv=(P32==5)
replace icv=. if P32>90
gen otropart=(P32==6 | P32==7 | P32==80)
replace otropart=. if P32>90
gen vote_noturnout=(P32==93 | P32==94 | P32==96)
replace vote_noturnout=. if P32==99
gen vote_unknown=(P32==98)
replace vote_unknown=. if P32==99
gen erc_old=(P30==3)
replace erc_old=. if P30>90
gen ciu_old=(P30==2)
replace ciu_old=. if P30>90
gen ppc_old=(P30==1)
replace ppc_old=. if P30>90
gen ppc_old_all=(P30==1)
replace ppc_old_all=. if P30>90
gen part_indep_old=(P30==2 | P30==3)
replace part_indep_old=. if P30>90
gen prox_erc=P22C
replace prox_erc=. if P22C>=98
gen prox_ciu=P22B
replace prox_ciu=. if P22B>=98
gen prox_part_indep=(P22C>=3 | P22B>=3)
replace prox_part_indep=. if P22C>=98 | P22B>=98

***Geography
gen provi_bcn=(PROVI==1)
gen provi_gir=(PROVI==2)
gen provi_lle=(PROVI==3)
gen provi_tar=(PROVI==4)
gen com_baixllob=(COMARCA==11)
gen com_bcn=(COMARCA==13)
gen com_gir=(COMARCA==20)
gen com_segria=(COMARCA==33)
gen com_tar=(COMARCA==36)
gen com_vallesocc=(COMARCA==40)
gen mun_0_2000=(HABITAT==1)
gen mun_2001_10000=(HABITAT==2)
gen mun_10001_50000=(HABITAT==3)
gen mun_50001_150000=(HABITAT==4)
gen mun_150001_1000000=(HABITAT==5)
gen mun_1000000=(HABITAT==6)
egen group_ps=group(PROVI HABITAT)
egen strata=group(PROVI HABITAT)
egen ssu=group(sexe gr_edat)

***World cup variables
gen post_match_29_6_10=0 if (DIA==28 | DIA==29) & survey=="3-2010"
replace post_match_29_6_10=1 if post_match_29_6_10==. & survey=="3-2010"
gen post_match_3_7_10=0 if (DIA==28 | DIA==29 | DIA==30 | DIA==1 | DIA==2 | DIA==3) & survey=="3-2010"
replace post_match_3_7_10=1 if post_match_3_7_10==. & survey=="3-2010"

***Interactions
gen est_ca_feel2=estatut*ca_feel2
gen est_ca_feel3=estatut*ca_feel3
gen est_ca_feel4=estatut*ca_feel4
gen est_ca_feel5=estatut*ca_feel5
gen est_cat_feeling=estatut*cat_feeling
gen est_female=estatut*female
gen est_casa_ca=estatut*casa_cat
gen est_amigos_ca=estatut*amigos_cat
gen est_erc_old=estatut*erc_old
gen est_ciu_old=estatut*ciu_old
gen est_ppc_old=estatut*ppc_old
gen est_ppc_old_all=estatut*ppc_old
gen est_part_indep_old=estatut*part_indep_old
gen est_edad_3549=estatut*edad_3549
gen est_edad_5064=estatut*edad_5064
gen est_edad_64=estatut*edad_64
gen est_mun_0_2000=estatut*mun_0_2000
gen est_mun_2001_10000=estatut*mun_2001_10000
gen est_mun_10001_50000=estatut*mun_10001_50000
gen est_mun_50001_150000=estatut*mun_50001_150000
gen est_mun_150001_1000000=estatut*mun_150001_1000000
gen est_casado=estatut*casado
gen est_educ_eso=estatut*educ_eso
gen est_educ_bach=estatut*educ_bach
gen est_educ_uni=estatut*educ_uni
gen est_ingr_1001_2000=estatut*ingr_1001_2000
gen est_ingr_2001_3000=estatut*ingr_2001_3000
gen est_ingr_3001=estatut*ingr_3001
gen est_empleo_aut=estatut*empleo_aut
gen est_empleo_dep=estatut*empleo_dep
gen est_nac_esp=estatut*nac_esp
gen est_nac_for=estatut*nac_for
gen est_nac_padre_esp=estatut*nac_padre_esp
gen est_nac_padre_for=estatut*nac_padre_for
gen est_nac_madre_esp=estatut*nac_madre_esp
gen est_nac_madre_for=estatut*nac_madre_for
gen est_si_padres=estatut*dnac_padres_kat_ambos
gen est_trust_trib=estatut*trust_trib
gen est_trust_parlesp=estatut*trust_parlesp
gen est_trust_part=estatut*trust_part
gen est_satisf_demo_poco=estatut*satisf_demo_poco
gen est_tv3=estatut*tv3

***Labels
label var estatut "Ruling"
label var cat_feeling "Feeling Catalan"
label var trust_trib "Trust courts"
label var trust_parlesp "Trust Spanish parliament"
label var trust_part "Trust political parties"
label var satisf_demo_poco "Insatisfaction democracy"
label var entr_cat "Interview in catalan"
label var casa_cat "Speak catalan at home"
label var trabajo_cat "Speak catalan at work"
label var amigos_cat "Speak catalan with friends"
label var nac_kat "Born in Catalonia"
label var nac_esp "Born in rest of Spain"
label var nac_for "Foreign born"
label var nac_padre_kat "Father born in Catalonia"
label var nac_padre_esp "Father born in rest of Spain"
label var nac_padre_for "Father foreign born"
label var nac_madre_kat "Mother born in Catalonia"
label var nac_madre_esp "Mother born in rest of Spain"
label var nac_madre_for "Mother foreign born"
label var dnac_padres_kat_ambos "Catalan heritage"
label var edad_1834 "Age 18-34"
label var edad_3549 "Age 35-49"
label var edad_5064 "Age 50-64"
label var edad_64 "Age 64 or more"
label var edat "Age"
label var edat2 "Age squared"
label var female "Female"
label var casado "Married"
label var educ_menoseso "Educ. lower ESO (6th grade)"
label var educ_eso "Educ. ESO (10th grade)"
label var educ_bach "Educ. Bachillerato (12th grade)"
label var educ_uni "Educ. university"
label var ingr_1000 "Net family income lower than 1k"
label var ingr_1001_2000 "Net family income 1k-2k"
label var ingr_2001_3000 "Net family income 2k-3k"
label var ingr_3001 "Income 3k or more"
label var empleo_aut "Self-employed"
label var empleo_dep "Employed"
label var empleo_unem "Unemployed"
label var mun_0_2000 "City pop. lower than 2k"
label var mun_2001_10000 "City pop. 2k-10k"
label var mun_10001_50000 "City pop. 10k-50k"
label var mun_50001_150000 "City pop. 50k-150k"
label var mun_150001_1000000 "City pop. 150k-1million"
label var mun_1000000 "City pop. 1 million or more"
label var d_HOR_INI_19 "Interview after 19"
label var d_time_7 "Interview after 7th day field work"
label var group_ps "Province x city size"
label var ppc_old "Past vote PPC"
label var ppc_old_all "Past vote PPC"
label var post_match_29_6_10 "Post-round of 16"
label var post_match_3_7_10 "Post-quarterfinal"
label var est_ca_feel2 "Ruling x +Esp than Cat"
label var est_ca_feel3 "Ruling x =Esp than Cat"
label var est_ca_feel4 "Ruling x -Esp than Cat"
label var est_ca_feel5 "Ruling x only Cat"
label var est_cat_feeling "Ruling x catalan feeling"
label var est_female "Ruling x female"
label var est_casa_ca "Ruling x speak catalan at home"
label var est_amigos_ca "Ruling x speak catalan with friends"
label var est_nac_esp "Ruling x born in rest of Spain"
label var est_nac_for "Ruling x foreign born"
label var est_nac_padre_esp "Ruling x father born in rest of Spain"
label var est_nac_padre_for "Ruling x father foreign born"
label var est_nac_madre_esp "Ruling x mother born in rest of Spain"
label var est_nac_madre_for "Ruling x mother foreign born"
label var est_si_padres "Ruling x Catalan heritage"
label var est_erc_old "Ruling x past vote ERC"
label var est_ciu_old "Ruling x past vote CiU"
label var est_ppc_old "Ruling x past vote PPC"
label var est_ppc_old_all "Ruling X Past vote PPC"
label var est_part_indep_old "Ruling x past vote ERC or CiU"
label var est_edad_3549 "Ruling x age 3549"
label var est_edad_5064 "Ruling x age 50-64"
label var est_edad_64 "Ruling x age 64 or more"
label var est_mun_0_2000 "Ruling x city pop. lower than 2k"
label var est_mun_2001_10000 "Ruling x city pop. 2k-10k"
label var est_mun_10001_50000 "Ruling x city pop. 10k-50k"
label var est_mun_50001_150000 "Ruling x city pop. 50k-150k"
label var est_mun_150001_1000000 "Ruling x city pop. 150k-1million"
label var est_casado "Ruling x married"
label var est_educ_eso "Ruling x educ. ESO (10th grade)"
label var est_educ_bach "Ruling x educ. Bachillerato (12th grade)"
label var est_educ_uni "Ruling x educ. university"
label var est_ingr_1001_2000 "Ruling x net family income 1k-2k"
label var est_ingr_2001_3000 "Ruling x net family income 2k-3k"
label var est_ingr_3001 "Ruling x net family income 3k or more"
label var est_empleo_aut "Ruling x self-employed"
label var est_empleo_dep "Ruling x employed"
label var est_trust_trib "Ruling x trust tribunals"
label var est_trust_parlesp "Ruling x Spanish parliament"
label var est_trust_part "Ruling x trust political parties"
label var est_satisf_demo_poco "Ruling x insatisfaction democracy"
label var est_tv3 "Ruling x TV3"

save data/final/data_ceo_restr.dta, replace

