clear all
set more off

*Set working directory
*cd "C:/Users/.../3-replication-package"

*******************************************************************************
***Padron 2010
*******************************************************************************
***Población a 1 de enero. Por lugar de nacimiento y sexo. Municipios. 2000-2022
import delimited using data/raw/pmh8284mun.csv, clear

rename año year
rename municipios NAMEMUN
destring valor, force replace
rename valor pob_
drop concepto estado

*Codes birth place (1: cat, 2: for, 3: cat_com, 4: cat_fueracom, 5: esp, 6: tot)
egen nac_code=group(lugardenacimiento)
drop lugardenacimiento

*Keep only 2010
keep if year==2010
drop year

*Keep only total population
keep if sexo=="total"
drop sexo

*Reshape
reshape wide pob_, i(NAMEMUN) j(nac_code)

rename pob_1 pob_nac_kat_10
rename pob_2 pob_nac_for_10
rename pob_3 pob_nac_kat_com_10
rename pob_4 pob_nac_kat_fueracom_10
rename pob_5 pob_nac_esp_10
rename pob_6 pob_tot_10

tempfile t1
save `t1'

***Población a 1 de enero. Por lugar de nacimiento, sexo y edad quinquenal. Municipios (de más de 5000 habitants). 2000-2022
import delimited using data/raw/pmh677mun.csv, clear

rename año year
rename municipios NAMEMUN
destring valor, force replace
rename valor pob_
drop concepto estado

*Codes birth place (1: cat, 2: for, 3: esp, 4: tot)
egen nac_code=group(lugardenacimiento)
drop lugardenacimiento

*Drop total population
drop if edad=="total"

*Codes age and birth place
egen nacedad_code=group(nac_code edad)
drop nac_code edad

*Keep only 2010
keep if year==2010
drop year

*Keep only total population
keep if sexo=="total"
drop sexo

*Reshape
reshape wide pob_, i(NAMEMUN) j(nacedad_code)

rename pob_1 pob_nac_kat_85_10
rename pob_2 pob_nac_kat_0004_10
rename pob_3 pob_nac_kat_1014_10
rename pob_4 pob_nac_kat_1519_10
rename pob_5 pob_nac_kat_2024_10
rename pob_6 pob_nac_kat_2529_10
rename pob_7 pob_nac_kat_3034_10
rename pob_8 pob_nac_kat_3539_10
rename pob_9 pob_nac_kat_4044_10
rename pob_10 pob_nac_kat_4549_10
rename pob_11 pob_nac_kat_0509_10
rename pob_12 pob_nac_kat_5054_10
rename pob_13 pob_nac_kat_5559_10
rename pob_14 pob_nac_kat_6064_10
rename pob_15 pob_nac_kat_6569_10
rename pob_16 pob_nac_kat_7074_10
rename pob_17 pob_nac_kat_7579_10
rename pob_18 pob_nac_kat_8084_10

rename pob_19 pob_nac_for_85_10
rename pob_20 pob_nac_for_0004_10
rename pob_21 pob_nac_for_1014_10
rename pob_22 pob_nac_for_1519_10
rename pob_23 pob_nac_for_2024_10
rename pob_24 pob_nac_for_2529_10
rename pob_25 pob_nac_for_3034_10
rename pob_26 pob_nac_for_3539_10
rename pob_27 pob_nac_for_4044_10
rename pob_28 pob_nac_for_4549_10
rename pob_29 pob_nac_for_0509_10
rename pob_30 pob_nac_for_5054_10
rename pob_31 pob_nac_for_5559_10
rename pob_32 pob_nac_for_6064_10
rename pob_33 pob_nac_for_6569_10
rename pob_34 pob_nac_for_7074_10
rename pob_35 pob_nac_for_7579_10
rename pob_36 pob_nac_for_8084_10

rename pob_37 pob_nac_esp_85_10
rename pob_38 pob_nac_esp_0004_10
rename pob_39 pob_nac_esp_1014_10
rename pob_40 pob_nac_esp_1519_10
rename pob_41 pob_nac_esp_2024_10
rename pob_42 pob_nac_esp_2529_10
rename pob_43 pob_nac_esp_3034_10
rename pob_44 pob_nac_esp_3539_10
rename pob_45 pob_nac_esp_4044_10
rename pob_46 pob_nac_esp_4549_10
rename pob_47 pob_nac_esp_0509_10
rename pob_48 pob_nac_esp_5054_10
rename pob_49 pob_nac_esp_5559_10
rename pob_50 pob_nac_esp_6064_10
rename pob_51 pob_nac_esp_6569_10
rename pob_52 pob_nac_esp_7074_10
rename pob_53 pob_nac_esp_7579_10
rename pob_54 pob_nac_esp_8084_10

rename pob_55 pob_85_10
rename pob_56 pob_0004_10
rename pob_57 pob_1014_10
rename pob_58 pob_1519_10
rename pob_59 pob_2024_10
rename pob_60 pob_2529_10
rename pob_61 pob_3034_10
rename pob_62 pob_3539_10
rename pob_63 pob_4044_10
rename pob_64 pob_4549_10
rename pob_65 pob_0509_10
rename pob_66 pob_5054_10
rename pob_67 pob_5559_10
rename pob_68 pob_6064_10
rename pob_69 pob_6569_10
rename pob_70 pob_7074_10
rename pob_71 pob_7579_10
rename pob_72 pob_8084_10

***Merge two information
merge 1:1 NAMEMUN using `t1'
drop _merge
*unmerged are municipalities with lower than 5,000 inhabitants

*Mediñá did not exist at the time, Mediñá and Sant Julià de Ramis formerly part of same municipality
*La Canonja independent from 2010 
drop if pob_tot_10==.
drop if NAMEMUN=="Catalunya"

tempfile t2
save `t2'

*******************************************************************************
***Merge codes and names of municipalities
*******************************************************************************
import delimited using data/raw/mpiscatalunya.csv, clear delim(";") rowrange(5:)

rename municipis CODMUN
rename v2 NAMEMUN
rename v3 COMARCA
rename v4 NAMECOMARCA
drop v5

merge 1:1 NAMEMUN using `t2'
drop _merge

tempfile t3
save `t3'

*******************************************************************************
***Censo 2011
*******************************************************************************
import delimited using data/raw/municipis.csv, clear

rename codmun CODMUN
rename a1 pob_tot_11
rename k1 pob_inkat_always_11
rename k2 pob_inkat_1970_11
rename k3 pob_inkat_1971_1990_11
rename k4 pob_inkat_1991_2000_11
rename k5 pob_inkat_2001_11
rename o1 pob_0002_11
rename o2 pob_0002_noundkat_11
rename o3 pob_0002_undkat_11
rename o4 pob_0002_speakkat_11
rename o5 pob_0002_readkat_11
rename o6 pob_0002_writekat_11
rename q1 pob_16_11
rename q2 pob_16_nostudy_11
rename q3 pob_16_1ststudy_11
rename q4 pob_16_2ndstudy_11
rename q5 pob_16_3rdstudy_11
rename s1 pob_16_active_11
rename s2 pob_16_empl_11
rename s3 pob_16_unempl_11
rename s4 pob_16_inactive_11
rename u1 pob_agric_11
rename u2 pob_industr_11
rename u3 pob_constr_11
rename u4 pob_serv_11

keep CODMUN pob*

merge 1:1 CODMUN using `t3'
drop _merge

generate CODIINE=int(CODMUN/10)

save data/final/data_padroncenso.dta, replace
